@@ -13,6 +13,7 @@
 #include "Author.h"
 
 #include "support/convert.h"
+#include "support/gettext.h"
 #include "support/lassert.h"
 #include "support/lstrings.h"
 
@@ -48,6 +49,15 @@ Author::Author(int buffer_id)
 {}
 
 
+docstring Author::nameAndEmail() const
+{
+	if (email().empty())
+		return name();
+	else
+		return bformat(_("%1$s[[name]] (%2$s[[email]])"), name(), email());
+}
+
+
 bool Author::valid() const
 {
 	//this cannot be equal if the buffer_id was produced by the hash function.
