@@ -15,6 +15,7 @@
 #ifndef BUFFERPARAMS_H
 #define BUFFERPARAMS_H
 
+#include "Author.h"
 #include "Citation.h"
 #include "DocumentClassPtr.h"
 #include "Format.h"
@@ -33,7 +34,6 @@ namespace lyx {
 
 namespace support { class FileName; }
 
-class AuthorList;
 class BranchList;
 class Bullet;
 class DocumentClass;
@@ -48,7 +48,6 @@ class LayoutFileIndex;
 class Lexer;
 class PDFOptions;
 class Spacing;
-class TexRow;
 class VSpace;
 
 /** Buffer parameters.
@@ -77,12 +76,12 @@ public:
 		support::FileName const & filepath);
 
 	///
-	void writeFile(std::ostream &) const;
+	void writeFile(std::ostream &, Buffer const *) const;
 
 	/// check what features are implied by the buffer parameters.
 	void validate(LaTeXFeatures &) const;
 
-	/** \returns true if the babel package is used (interogates
+	/** \returns true if the babel package is used (interrogates
 	 *  the BufferParams, a LyXRC variable, and the document class).
 	 *  This returned value can then be passed to the insets...
 	 */
@@ -110,8 +109,6 @@ public:
 	///
 	InsetQuotes::QuoteLanguage quotes_language;
 	///
-	InsetQuotes::QuoteTimes quotes_times;
-	///
 	std::string fontsize;
 	/// Get the LayoutFile this document is using.
 	LayoutFile const * baseClass() const;
@@ -120,7 +117,7 @@ public:
 	/// Set the LyX layout file this document is using.
 	/// NOTE: This does not call makeDocumentClass() to update the local
 	/// DocumentClass. That needs to be done manually.
-	/// \param filename the name of the layout file
+	/// \param classname: the name of the layout file
 	bool setBaseClass(std::string const & classname);
 	/// Adds the module information to the baseClass information to
 	/// create our local DocumentClass.
@@ -180,7 +177,7 @@ public:
 	std::string getDefaultOutputFormat() const;
 	/// return the output flavor of \p format or the default
 	OutputParams::FLAVOR getOutputFlavor(
-		  std::string const format = std::string()) const;
+		  std::string const & format = std::string()) const;
 	///
 	bool isExportable(std::string const & format) const;
 	///
@@ -207,7 +204,7 @@ public:
 	Font const getFont() const;
 
 	/// translate quote style string to enum value
-	InsetQuotes::QuoteLanguage getQuoteStyle(std::string const qs) const;
+	InsetQuotes::QuoteLanguage getQuoteStyle(std::string const & qs) const;
 
 	/* these are for the PaperLayout */
 	/// the papersize
@@ -246,16 +243,24 @@ public:
 	std::string bibtex_command;
 	/// customized index processor
 	std::string index_command;
-	/// font encoding
+	/// font encoding(s) requested for this document
 	std::string fontenc;
+	/// the rm font: [0] for TeX fonts, [1] for non-TeX fonts
+	std::string fonts_roman[2];
 	/// the rm font
-	std::string fonts_roman;
+	std::string const & fontsRoman() const { return fonts_roman[useNonTeXFonts]; }
+	/// the sf font: [0] for TeX fonts, [1] for non-TeX fonts
+	std::string fonts_sans[2];
 	/// the sf font
-	std::string fonts_sans;
+	std::string const & fontsSans() const { return fonts_sans[useNonTeXFonts]; }
+	/// the tt font: [0] for TeX fonts, [1] for non-TeX fonts
+	std::string fonts_typewriter[2];
 	/// the tt font
-	std::string fonts_typewriter;
+	std::string const & fontsTypewriter() const { return fonts_typewriter[useNonTeXFonts]; }
+	/// the math font: [0] for TeX fonts, [1] for non-TeX fonts
+	std::string fonts_math[2];
 	/// the math font
-	std::string fonts_math;
+	std::string const & fontsMath() const { return fonts_math[useNonTeXFonts]; }
 	/// the default family (rm, sf, tt)
 	std::string fonts_default_family;
 	/// use the fonts of the OS (OpenType, True Type) directly
@@ -264,10 +269,14 @@ public:
 	bool fonts_expert_sc;
 	/// use Old Style Figures
 	bool fonts_old_figures;
+	/// the scale factor of the sf font: [0] for TeX fonts, [1] for non-TeX fonts
+	int fonts_sans_scale[2];
 	/// the scale factor of the sf font
-	int fonts_sans_scale;
+	int fontsSansScale() const { return fonts_sans_scale[useNonTeXFonts]; }
+	/// the scale factor of the tt font: [0] for TeX fonts, [1] for non-TeX fonts
+	int fonts_typewriter_scale[2];
 	/// the scale factor of the tt font
-	int fonts_typewriter_scale;
+	int fontsTypewriterScale() const { return fonts_typewriter_scale[useNonTeXFonts]; }
 	/// the font used by the CJK command
 	std::string fonts_cjk;
 	///
@@ -305,8 +314,12 @@ public:
 	std::string inputenc;
 	/// The main encoding used by this buffer for LaTeX output.
 	/// Individual pieces of text can use different encodings.
+	/// Output for XeTeX with 8-bit TeX fonts uses ASCII (set at runtime)
+	/// instead of the value returned by this function.
 	Encoding const & encoding() const;
 	///
+	std::string origin;
+	///
 	std::string preamble;
 	///
 	std::string options;
@@ -368,25 +381,34 @@ public:
 	bool use_bibtopic;
 	/// Split the index?
 	bool use_indices;
-	/// revision tracking for this buffer ?
-	bool trackChanges;
+	/// Save trensient properties?
+	bool save_transient_properties;
+	/// revision tracking for this buffer ? (this is a transient property)
+	bool track_changes;
 	/** This param decides whether change tracking marks should be used
 	 *  in output (irrespective of how these marks are actually defined;
 	 *  for instance, they may differ for DVI and PDF generation)
+	 *  This is a transient property.
 	 */
-	bool outputChanges;
+	bool output_changes;
 	///
 	bool compressed;
 
 	/// the author list for the document
 	AuthorList & authors();
 	AuthorList const & authors() const;
+	void addAuthor(Author a);
 
 	/// map of the file's author IDs to AuthorList indexes
 	typedef std::map<int, int> AuthorMap;
-	AuthorMap author_map;
-	/// the buffer's font encoding
+	AuthorMap author_map_;
+
+	/// the buffer's active font encoding
 	std::string const font_encoding() const;
+	/// all font encodings requested by the prefs/document/main language.
+	/// This does NOT include font encodings required by secondary languages
+	std::vector<std::string> const font_encodings() const;
+
 	///
 	std::string const dvips_options() const;
 	/** The return value of paperSizeName() depends on the
@@ -465,6 +487,8 @@ public:
 	///
 	double html_math_img_scale;
 	///
+	double display_pixel_ratio;
+	///
 	std::string html_latex_start;
 	///
 	std::string html_latex_end;
