@@ -1509,14 +1509,8 @@ void BufferView::dispatch(FuncRequest const & cmd, DispatchResult & dr)
 		docstring const data =
 			find2string(searched_string, true, false, fw);
 		bool found = lyxfind(this, FuncRequest(LFUN_WORD_FIND, data));
-		if (found) {
+		if (found)
 			dr.screenUpdate(Update::Force | Update::FitCursor);
-			cur.dispatched();
-			dispatched = true;
-		} else {
-			cur.undispatched();
-			dispatched = false;
-		}
 		break;
 	}
 
@@ -1528,14 +1522,9 @@ void BufferView::dispatch(FuncRequest const & cmd, DispatchResult & dr)
 			lyx::dispatch(FuncRequest(LFUN_DIALOG_SHOW, "findreplace"));
 			break;
 		}
-		if (lyxfind(this, req)) {
+		if (lyxfind(this, req))
 			dr.screenUpdate(Update::Force | Update::FitCursor);
-			cur.dispatched();
-			dispatched = true;
-		} else {
-			cur.undispatched();
-			dispatched = false;
-		}
+
 		d->search_request_cache_ = req;
 		break;
 	}
@@ -1557,11 +1546,6 @@ void BufferView::dispatch(FuncRequest const & cmd, DispatchResult & dr)
 		if (lyxreplace(this, cmd, has_deleted)) {
 			dr.forceBufferUpdate();
 			dr.screenUpdate(Update::Force | Update::FitCursor);
-			cur.dispatched();
-			dispatched = true;
-		} else {
-			cur.undispatched();
-			dispatched = false;
 		}
 		break;
 	}
@@ -2894,7 +2878,7 @@ bool BufferView::paragraphVisible(DocIterator const & dit) const
 void BufferView::cursorPosAndHeight(Point & p, int & h) const
 {
 	Cursor const & cur = cursor();
-	Font const font = cur.getFont();
+	Font const font = cur.real_current_font;
 	frontend::FontMetrics const & fm = theFontMetrics(font);
 	int const asc = fm.maxAscent();
 	int const des = fm.maxDescent();
