@@ -29,10 +29,11 @@
 #include "support/FileNameList.h"
 #include "support/filetools.h"
 #include "support/gettext.h"
+#include "support/lassert.h"
 #include "support/lstrings.h"
 #include "support/os.h"
 #include "support/Package.h"
-#include "support/Path.h"
+#include "support/PathChanger.h"
 #include "support/Systemcall.h"
 
 using namespace std;
@@ -52,6 +53,7 @@ string const token_path("$$p");
 string const token_orig_path("$$r");
 string const token_orig_from("$$f");
 string const token_encoding("$$e");
+string const token_latex_encoding("$$E");
 
 
 string const add_options(string const & command, string const & options)
@@ -84,7 +86,7 @@ public:
 	ConverterEqual(string const & from, string const & to)
 		: from_(from), to_(to) {}
 	bool operator()(Converter const & c) const {
-		return c.from == from_ && c.to == to_;
+		return c.from() == from_ && c.to() == to_;
 	}
 private:
 	string const from_;
@@ -96,57 +98,44 @@ private:
 
 Converter::Converter(string const & f, string const & t,
 		     string const & c, string const & l)
-	: from(f), to(t), command(c), flags(l),
-	  From(0), To(0), latex(false), xml(false),
-	  need_aux(false)
+	: from_(f), to_(t), command_(c), flags_(l),
+	  From_(0), To_(0), latex_(false), xml_(false),
+	  need_aux_(false), nice_(false)
 {}
 
 
 void Converter::readFlags()
 {
-	string flag_list(flags);
+	string flag_list(flags_);
 	while (!flag_list.empty()) {
 		string flag_name, flag_value;
 		flag_list = split(flag_list, flag_value, ',');
 		flag_value = split(flag_value, flag_name, '=');
 		if (flag_name == "latex") {
-			latex = true;
-			latex_flavor = flag_value.empty() ?
+			latex_ = true;
+			latex_flavor_ = flag_value.empty() ?
 				"latex" : flag_value;
 		} else if (flag_name == "xml")
-			xml = true;
+			xml_ = true;
 		else if (flag_name == "needaux")
-			need_aux = true;
+			need_aux_ = true;
 		else if (flag_name == "resultdir")
-			result_dir = (flag_value.empty())
+			result_dir_ = (flag_value.empty())
 				? token_base : flag_value;
 		else if (flag_name == "resultfile")
-			result_file = flag_value;
+			result_file_ = flag_value;
 		else if (flag_name == "parselog")
-			parselog = flag_value;
+			parselog_ = flag_value;
+		else if (flag_name == "nice")
+			nice_ = true;
 	}
-	if (!result_dir.empty() && result_file.empty())
-		result_file = "index." + formats.extension(to);
+	if (!result_dir_.empty() && result_file_.empty())
+		result_file_ = "index." + formats.extension(to_);
 	//if (!contains(command, token_from))
 	//	latex = true;
 }
 
 
-bool operator<(Converter const & a, Converter const & b)
-{
-	// use the compare_ascii_no_case instead of compare_no_case,
-	// because in turkish, 'i' is not the lowercase version of 'I',
-	// and thus turkish locale breaks parsing of tags.
-	int const i = compare_ascii_no_case(a.From->prettyname(),
-					    b.From->prettyname());
-	if (i == 0)
-		return compare_ascii_no_case(a.To->prettyname(),
-					     b.To->prettyname()) < 0;
-	else
-		return i < 0;
-}
-
-
 Converter const * Converters::getConverter(string const & from,
 					    string const & to) const
 {
@@ -184,36 +173,36 @@ void Converters::add(string const & from, string const & to,
 	Converter converter(from, to, command, flags);
 	if (it != converterlist_.end() && !flags.empty() && flags[0] == '*') {
 		converter = *it;
-		converter.command = command;
-		converter.flags = flags;
+		converter.setCommand(command);
+		converter.setFlags(flags);
 	}
 	converter.readFlags();
 
 	// The latex_command is used to update the .aux file when running
 	// a converter that uses it.
-	if (converter.latex) {
+	if (converter.latex()) {
 		if (latex_command_.empty() ||
-		    converter.latex_flavor == "latex")
+		    converter.latex_flavor() == "latex")
 			latex_command_ = subst(command, token_from, "");
 		if (dvilualatex_command_.empty() ||
-		    converter.latex_flavor == "dvilualatex")
+		    converter.latex_flavor() == "dvilualatex")
 			dvilualatex_command_ = subst(command, token_from, "");
 		if (lualatex_command_.empty() ||
-		    converter.latex_flavor == "lualatex")
+		    converter.latex_flavor() == "lualatex")
 			lualatex_command_ = subst(command, token_from, "");
 		if (pdflatex_command_.empty() ||
-		    converter.latex_flavor == "pdflatex")
+		    converter.latex_flavor() == "pdflatex")
 			pdflatex_command_ = subst(command, token_from, "");
 		if (xelatex_command_.empty() ||
-		    converter.latex_flavor == "xelatex")
+		    converter.latex_flavor() == "xelatex")
 			xelatex_command_ = subst(command, token_from, "");
 	}
 
 	if (it == converterlist_.end()) {
 		converterlist_.push_back(converter);
 	} else {
-		converter.From = it->From;
-		converter.To = it->To;
+		converter.setFrom(it->From());
+		converter.setTo(it->To());
 		*it = converter;
 	}
 }
@@ -242,8 +231,8 @@ void Converters::update(Formats const & formats)
 	ConverterList::iterator it = converterlist_.begin();
 	ConverterList::iterator end = converterlist_.end();
 	for (; it != end; ++it) {
-		it->From = formats.getFormat(it->from);
-		it->To = formats.getFormat(it->to);
+		it->setFrom(formats.getFormat(it->from()));
+		it->setTo(formats.getFormat(it->to()));
 	}
 }
 
@@ -254,37 +243,31 @@ void Converters::updateLast(Formats const & formats)
 {
 	if (converterlist_.begin() != converterlist_.end()) {
 		ConverterList::iterator it = converterlist_.end() - 1;
-		it->From = formats.getFormat(it->from);
-		it->To = formats.getFormat(it->to);
+		it->setFrom(formats.getFormat(it->from()));
+		it->setTo(formats.getFormat(it->to()));
 	}
 }
 
 
-void Converters::sort()
-{
-	std::sort(converterlist_.begin(), converterlist_.end());
-}
-
-
 OutputParams::FLAVOR Converters::getFlavor(Graph::EdgePath const & path,
 					   Buffer const * buffer)
 {
 	for (Graph::EdgePath::const_iterator cit = path.begin();
 	     cit != path.end(); ++cit) {
 		Converter const & conv = converterlist_[*cit];
-		if (conv.latex) {
-			if (conv.latex_flavor == "latex")
+		if (conv.latex()) {
+			if (conv.latex_flavor() == "latex")
 				return OutputParams::LATEX;
-			if (conv.latex_flavor == "xelatex")
+			if (conv.latex_flavor() == "xelatex")
 				return OutputParams::XETEX;
-			if (conv.latex_flavor == "lualatex")
+			if (conv.latex_flavor() == "lualatex")
 				return OutputParams::LUATEX;
-			if (conv.latex_flavor == "dvilualatex")
+			if (conv.latex_flavor() == "dvilualatex")
 				return OutputParams::DVILUATEX;
-			if (conv.latex_flavor == "pdflatex")
+			if (conv.latex_flavor() == "pdflatex")
 				return OutputParams::PDFLATEX;
 		}
-		if (conv.xml)
+		if (conv.xml())
 			return OutputParams::XML;
 	}
 	return buffer ? buffer->params().getOutputFlavor()
@@ -317,15 +300,16 @@ bool Converters::convert(Buffer const * buffer,
 			string const command =
 				os::python() + ' ' +
 				quoteName(libFileSearch("scripts", "convertDefault.py").toFilesystemEncoding()) +
-				' ' +
-				quoteName(from_ext + ':' + from_file.toFilesystemEncoding()) +
-				' ' +
-				quoteName(to_ext + ':' + to_file.toFilesystemEncoding());
+				' ' + from_ext + ' ' +
+				quoteName(from_file.toFilesystemEncoding()) +
+				' ' + to_ext + ' ' +
+				quoteName(to_file.toFilesystemEncoding());
 			LYXERR(Debug::FILES, "No converter defined! "
 				   "I use convertDefault.py:\n\t" << command);
 			Systemcall one;
-			one.startscript(Systemcall::Wait, command, buffer ?
-					buffer->filePath() : string());
+			one.startscript(Systemcall::Wait, command,
+			                buffer ? buffer->filePath() : string(),
+			                buffer ? buffer->layoutPos() : string());
 			if (to_file.isReadableFile()) {
 				if (conversionflags & try_cache)
 					ConverterCache::get().add(orig_from,
@@ -361,6 +345,7 @@ bool Converters::convert(Buffer const * buffer,
 			string() : buffer->params().bibtex_command;
 		runparams.index_command = (buffer->params().index_command == "default") ?
 			string() : buffer->params().index_command;
+		runparams.document_language = buffer->params().language->babel();
 	}
 
 	// Some converters (e.g. lilypond) can only output files to the
@@ -368,6 +353,8 @@ bool Converters::convert(Buffer const * buffer,
 	// This has the added benefit that all other files that may be
 	// generated by the converter are deleted when LyX closes and do not
 	// clutter the real working directory.
+	// FIXME: This does not work if path is an UNC path on windows
+	//        (bug 6127).
 	string const path(onlyPath(from_file.absFileName()));
 	// Prevent the compiler from optimizing away p
 	FileName pp(path);
@@ -384,22 +371,25 @@ bool Converters::convert(Buffer const * buffer,
 	for (Graph::EdgePath::const_iterator cit = edgepath.begin();
 	     cit != edgepath.end(); ++cit) {
 		Converter const & conv = converterlist_[*cit];
-		bool dummy = conv.To->dummy() && conv.to != "program";
+		bool dummy = conv.To()->dummy() && conv.to() != "program";
 		if (!dummy) {
 			LYXERR(Debug::FILES, "Converting from  "
-			       << conv.from << " to " << conv.to);
+			       << conv.from() << " to " << conv.to());
 		}
 		infile = outfile;
-		outfile = FileName(conv.result_dir.empty()
-			? changeExtension(from_file.absFileName(), conv.To->extension())
-			: addName(subst(conv.result_dir,
+		outfile = FileName(conv.result_file().empty()
+			? changeExtension(from_file.absFileName(), conv.To()->extension())
+			: addName(subst(conv.result_dir(),
 					token_base, from_base),
-				  subst(conv.result_file,
+				  subst(conv.result_file(),
 					token_base, onlyFileName(from_base))));
 
 		// if input and output files are equal, we use a
 		// temporary file as intermediary (JMarc)
 		FileName real_outfile;
+		if (!conv.result_file().empty())
+			real_outfile = FileName(changeExtension(from_file.absFileName(),
+				conv.To()->extension()));
 		if (outfile == infile) {
 			real_outfile = infile;
 			// when importing, a buffer does not necessarily exist
@@ -410,14 +400,17 @@ bool Converters::convert(Buffer const * buffer,
 						   "tmpfile.out"));
 		}
 
-		if (conv.latex) {
+		if (conv.latex()) {
 			run_latex = true;
-			string const command = subst(conv.command, token_from, "");
+			string command = conv.command();
+			command = subst(command, token_from, "");
+			command = subst(command, token_latex_encoding, buffer ?
+				buffer->params().encoding().latexName() : string());
 			LYXERR(Debug::FILES, "Running " << command);
 			if (!runLaTeX(*buffer, command, runparams, errorList))
 				return false;
 		} else {
-			if (conv.need_aux && !run_latex) {
+			if (conv.need_aux() && !run_latex) {
 				string command;
 				switch (runparams.flavor) {
 				case OutputParams::DVILUATEX:
@@ -452,7 +445,7 @@ bool Converters::convert(Buffer const * buffer,
 			string const outfile2 =
 				to_utf8(makeRelPath(from_utf8(outfile.absFileName()), from_utf8(path)));
 
-			string command = conv.command;
+			string command = conv.command();
 			command = subst(command, token_from, quoteName(infile2));
 			command = subst(command, token_base, quoteName(from_base));
 			command = subst(command, token_to, quoteName(outfile2));
@@ -460,15 +453,16 @@ bool Converters::convert(Buffer const * buffer,
 			command = subst(command, token_orig_path, quoteName(onlyPath(orig_from.absFileName())));
 			command = subst(command, token_orig_from, quoteName(onlyFileName(orig_from.absFileName())));
 			command = subst(command, token_encoding, buffer ? buffer->params().encoding().iconvName() : string());
-			command = libScriptSearch(command);
 
-			if (!conv.parselog.empty())
+			if (!conv.parselog().empty())
 				command += " 2> " + quoteName(infile2 + ".out");
 
-			if (conv.from == "dvi" && conv.to == "ps")
+			// it is not actually not necessary to test for buffer here,
+			// but it pleases coverity.
+			if (buffer && conv.from() == "dvi" && conv.to() == "ps")
 				command = add_options(command,
 						      buffer->params().dvips_options());
-			else if (conv.from == "dvi" && prefixIs(conv.to, "pdf"))
+			else if (buffer && conv.from() == "dvi" && prefixIs(conv.to(), "pdf"))
 				command = add_options(command,
 						      dvipdfm_options(buffer->params()));
 
@@ -482,16 +476,19 @@ bool Converters::convert(Buffer const * buffer,
 			if (dummy) {
 				res = one.startscript(Systemcall::DontWait,
 					to_filesystem8bit(from_utf8(command)),
-					buffer ? buffer->filePath() : string());
+					buffer ? buffer->filePath() : string(),
+					buffer ? buffer->layoutPos() : string());
 				// We're not waiting for the result, so we can't do anything
 				// else here.
 			} else {
 				res = one.startscript(Systemcall::Wait,
 						to_filesystem8bit(from_utf8(command)),
 						buffer ? buffer->filePath()
+						       : string(),
+						buffer ? buffer->layoutPos()
 						       : string());
 				if (!real_outfile.empty()) {
-					Mover const & mover = getMover(conv.to);
+					Mover const & mover = getMover(conv.to());
 					if (!mover.rename(outfile, real_outfile))
 						res = -1;
 					else
@@ -501,23 +498,23 @@ bool Converters::convert(Buffer const * buffer,
 					// converters to use the renamed file...
 					outfile = real_outfile;
 				}
-  
-				if (!conv.parselog.empty()) {
+
+				if (!conv.parselog().empty()) {
 					string const logfile =  infile2 + ".log";
-					string const script = libScriptSearch(conv.parselog);
-					string const command2 = script +
+					string const command2 = conv.parselog() +
 						" < " + quoteName(infile2 + ".out") +
 						" > " + quoteName(logfile);
 					one.startscript(Systemcall::Wait,
 						to_filesystem8bit(from_utf8(command2)),
-						buffer->filePath());
+						buffer->filePath(),
+						buffer->layoutPos());
 					if (!scanLog(*buffer, command, makeAbsPath(logfile, path), errorList))
 						return false;
 				}
 			}
 
 			if (res) {
-				if (conv.to == "program") {
+				if (conv.to() == "program") {
 					Alert::error(_("Build errors"),
 						_("There were errors during the build process."));
 				} else {
@@ -533,18 +530,18 @@ bool Converters::convert(Buffer const * buffer,
 	}
 
 	Converter const & conv = converterlist_[edgepath.back()];
-	if (conv.To->dummy())
+	if (conv.To()->dummy())
 		return true;
 
-	if (!conv.result_dir.empty()) {
+	if (!conv.result_dir().empty()) {
 		// The converter has put the file(s) in a directory.
 		// In this case we ignore the given to_file.
 		if (from_base != to_base) {
-			string const from = subst(conv.result_dir,
+			string const from = subst(conv.result_dir(),
 					    token_base, from_base);
-			string const to = subst(conv.result_dir,
+			string const to = subst(conv.result_dir(),
 					  token_base, to_base);
-			Mover const & mover = getMover(conv.from);
+			Mover const & mover = getMover(conv.from());
 			if (!mover.rename(FileName(from), FileName(to))) {
 				Alert::error(_("Cannot convert file"),
 					bformat(_("Could not move a temporary directory from %1$s to %2$s."),
@@ -556,7 +553,7 @@ bool Converters::convert(Buffer const * buffer,
 	} else {
 		if (conversionflags & try_cache)
 			ConverterCache::get().add(orig_from, to_format, outfile);
-		return move(conv.to, outfile, to_file, conv.latex);
+		return move(conv.to(), outfile, to_file, conv.latex());
 	}
 }
 
@@ -607,7 +604,7 @@ bool Converters::formatIsUsed(string const & format)
 	ConverterList::const_iterator cit = converterlist_.begin();
 	ConverterList::const_iterator end = converterlist_.end();
 	for (; cit != end; ++cit) {
-		if (cit->from == format || cit->to == format)
+		if (cit->from() == format || cit->to() == format)
 			return true;
 	}
 	return false;
@@ -650,12 +647,11 @@ bool Converters::runLaTeX(Buffer const & buffer, string const & command,
 	buffer.setBusy(true);
 	buffer.message(_("Running LaTeX..."));
 
-	runparams.document_language = buffer.params().language->babel();
-
 	// do the LaTeX run(s)
 	string const name = buffer.latexName();
 	LaTeX latex(command, runparams, FileName(makeAbsPath(name)),
-		    buffer.filePath());
+	            buffer.filePath(), buffer.layoutPos(),
+	            buffer.lastPreviewError());
 	TeXErrors terr;
 	ShowMessage show(buffer);
 	latex.message.connect(show);
@@ -664,16 +660,27 @@ bool Converters::runLaTeX(Buffer const & buffer, string const & command,
 	if (result & LaTeX::ERRORS)
 		buffer.bufferErrors(terr, errorList);
 
-	// check return value from latex.run().
-	if ((result & LaTeX::NO_LOGFILE) && !buffer.isClone()) {
+	if (!errorList.empty()) {
+	  // We will show the LaTeX Errors GUI later which contains
+	  // specific error messages so it would be repetitive to give
+	  // e.g. the "finished with an error" dialog in addition.
+	}
+	else if (result & LaTeX::NO_LOGFILE) {
 		docstring const str =
 			bformat(_("LaTeX did not run successfully. "
 					       "Additionally, LyX could not locate "
 					       "the LaTeX log %1$s."), from_utf8(name));
 		Alert::error(_("LaTeX failed"), str);
-	} else if ((result & LaTeX::NO_OUTPUT) && !buffer.isClone()) {
+	} else if (result & LaTeX::NONZERO_ERROR) {
+		docstring const str =
+			bformat(_( "The external program\n%1$s\n"
+			      "finished with an error. "
+			      "It is recommended you fix the cause of the external "
+			      "program's error (check the logs). "), from_utf8(command));
+		Alert::error(_("LaTeX failed"), str);
+	} else if (result & LaTeX::NO_OUTPUT) {
 		Alert::warning(_("Output is empty"),
-			       _("An empty output file was generated."));
+			       _("No output file was generated."));
 	}
 
 
@@ -685,7 +692,6 @@ bool Converters::runLaTeX(Buffer const & buffer, string const & command,
 			LaTeX::NO_OUTPUT;
 
 	return (result & ERROR_MASK) == 0;
-
 }
 
 
@@ -695,13 +701,15 @@ void Converters::buildGraph()
 	// clear graph's data structures
 	G_.init(formats.size());
 	// each of the converters knows how to convert one format to another
-	// so, for each of them, we create an arrow on the graph, going from 
+	// so, for each of them, we create an arrow on the graph, going from
 	// the one to the other
 	ConverterList::iterator it = converterlist_.begin();
 	ConverterList::iterator const end = converterlist_.end();
 	for (; it != end ; ++it) {
-		int const from = formats.getNumber(it->from);
-		int const to   = formats.getNumber(it->to);
+		int const from = formats.getNumber(it->from());
+		int const to   = formats.getNumber(it->to());
+		LASSERT(from >= 0, continue);
+		LASSERT(to >= 0, continue);
 		G_.addEdge(from, to);
 	}
 }
@@ -736,7 +744,7 @@ vector<Format const *> const
 Converters::getReachable(string const & from, bool const only_viewable,
 			 bool const clear_visited, set<string> const & excludes)
 {
-	set<int> excluded_numbers;;
+	set<int> excluded_numbers;
 
 	set<string>::const_iterator sit = excludes.begin();
 	set<string>::const_iterator const end = excludes.end();
