@@ -49,13 +49,14 @@ unsigned long do_crc(string const & s)
 }
 
 
+// FIXME THREAD
+// This should be OK because it is only assigned during init()
 static FileName cache_dir;
 
 
 class CacheItem {
 public:
-	CacheItem()
-	{}
+	CacheItem() : timestamp(0), checksum(0) {}
 	CacheItem(FileName const & orig_from, string const & to_format,
 		  time_t t, unsigned long c)
 		: timestamp(t), checksum(c)
@@ -222,6 +223,7 @@ ConverterCache::~ConverterCache()
 }
 
 
+// FIXME THREAD
 ConverterCache & ConverterCache::get()
 {
 	// Now return the cache
