@@ -15,7 +15,7 @@
 #include "CursorSlice.h"
 
 #include <vector>
-
+#include <algorithm>
 
 namespace lyx {
 
@@ -75,6 +75,9 @@ public:
 	/// is this the last possible position?
 	bool atLastPos() const { return pit() == lastpit() && pos() == lastpos(); }
 
+	/// checks the cursor slices for disabled spell checker insets
+	bool allowSpellCheck() const;
+
 	//
 	// access to slice at tip
 	//
@@ -164,6 +167,8 @@ public:
 	Paragraph & innerParagraph() const;
 	/// return the inner text slice.
 	CursorSlice const & innerTextSlice() const;
+	/// returns a DocIterator for the containing text inset
+	DocIterator getInnerText() const;
 	/// the first and last positions of a word at top cursor slice
 	/// \warning only works within text!
 	FontSpan locateWord(word_location const loc) const;
@@ -202,7 +207,7 @@ public:
 	/// move backward one paragraph
 	void backwardPar();
 	/// move backward one inset
-	/// FIXME: This is not implemented!
+	/// not used currently, uncomment if you need it
 	//void backwardInset();
 
 	/// are we some 'extension' (i.e. deeper nested) of the given iterator
