@@ -191,12 +191,25 @@ static docstring const changetracking_dvipost_def = from_ascii(
 static docstring const changetracking_xcolor_ulem_def = from_ascii(
 	"%% Change tracking with ulem\n"
 	"\\DeclareRobustCommand{\\lyxadded}[3]{{\\color{lyxadded}{}#3}}\n"
-	"\\DeclareRobustCommand{\\lyxdeleted}[3]{{\\color{lyxdeleted}\\sout{#3}}}\n");
+	"\\DeclareRobustCommand{\\lyxdeleted}[3]{{\\color{lyxdeleted}\\lyxsout{#3}}}\n"
+	"\\DeclareRobustCommand{\\lyxsout}[1]{\\ifx\\\\#1\\else\\sout{#1}\\fi}\n");
 
 static docstring const changetracking_xcolor_ulem_hyperref_def = from_ascii(
 	"%% Change tracking with ulem\n"
 	"\\DeclareRobustCommand{\\lyxadded}[3]{{\\texorpdfstring{\\color{lyxadded}{}}{}#3}}\n"
-	"\\DeclareRobustCommand{\\lyxdeleted}[3]{{\\texorpdfstring{\\color{lyxdeleted}\\sout{#3}}{}}}\n");
+	"\\DeclareRobustCommand{\\lyxdeleted}[3]{{\\texorpdfstring{\\color{lyxdeleted}\\lyxsout{#3}}{}}}\n"
+	"\\DeclareRobustCommand{\\lyxsout}[1]{\\ifx\\\\#1\\else\\sout{#1}\\fi}\n");
+
+static docstring const changetracking_tikz_math_sout_def = from_ascii(
+	"%% Strike out display math with tikz\n"
+	"\\usepackage{tikz}\n"
+	"\\usetikzlibrary{calc}\n"
+	"\\newcommand{\\lyxmathsout}[1]{%\n"
+	"  \\tikz[baseline=(math.base)]{\n"
+	"    \\node[inner sep=0pt,outer sep=0pt](math){#1};\n"
+	"    \\draw($(math.south west)+(2em,.5em)$)--($(math.north east)-(2em,.5em)$);\n"
+	"  }\n"
+	"}\n");
 
 static docstring const changetracking_none_def = from_ascii(
 	"\\newcommand{\\lyxadded}[3]{#3}\n"
@@ -388,7 +401,8 @@ static docstring const lyxstrikeout_style = from_ascii(
 
 LaTeXFeatures::LaTeXFeatures(Buffer const & b, BufferParams const & p,
 			     OutputParams const & r)
-	: buffer_(&b), params_(p), runparams_(r), in_float_(false)
+	: buffer_(&b), params_(p), runparams_(r), in_float_(false),
+	  in_deleted_inset_(false)
 {}
 
 
@@ -683,6 +697,42 @@ bool LaTeXFeatures::hasPolyglossiaExclusiveLanguages() const
 }
 
 
+vector<string> LaTeXFeatures::getPolyglossiaExclusiveLanguages() const
+{
+	vector<string> result;
+	// first the main language
+	if (params_.language->isPolyglossiaExclusive())
+		result.push_back(params_.language->display());
+	// now the secondary languages
+	LanguageList::const_iterator const begin = UsedLanguages_.begin();
+	for (LanguageList::const_iterator cit = begin;
+	     cit != UsedLanguages_.end();
+	     ++cit) {
+		if ((*cit)->isPolyglossiaExclusive())
+			result.push_back((*cit)->display());
+	}
+	return result;
+}
+
+
+vector<string> LaTeXFeatures::getBabelExclusiveLanguages() const
+{
+	vector<string> result;
+	// first the main language
+	if (params_.language->isBabelExclusive())
+		result.push_back(params_.language->display());
+	// now the secondary languages
+	LanguageList::const_iterator const begin = UsedLanguages_.begin();
+	for (LanguageList::const_iterator cit = begin;
+	     cit != UsedLanguages_.end();
+	     ++cit) {
+		if ((*cit)->isBabelExclusive())
+			result.push_back((*cit)->display());
+	}
+	return result;
+}
+
+
 string LaTeXFeatures::getBabelLanguages() const
 {
 	ostringstream languages;
@@ -704,15 +754,16 @@ string LaTeXFeatures::getBabelLanguages() const
 }
 
 
-std::map<std::string, std::string> LaTeXFeatures::getPolyglossiaLanguages() const
+set<string> LaTeXFeatures::getPolyglossiaLanguages() const
 {
-	std::map<std::string, std::string> languages;
+	set<string> languages;
 
 	LanguageList::const_iterator const begin = UsedLanguages_.begin();
 	for (LanguageList::const_iterator cit = begin;
 	     cit != UsedLanguages_.end();
 	     ++cit) {
-		languages[(*cit)->polyglossia()] = (*cit)->polyglossiaOpts();
+		// We do not need the variants here
+		languages.insert((*cit)->polyglossia());
 	}
 	return languages;
 }
@@ -1330,6 +1381,9 @@ docstring const LaTeXFeatures::getMacros() const
 			macros << changetracking_xcolor_ulem_def;
 	}
 
+	if (mustProvide("ct-tikz-math-sout"))
+			macros << changetracking_tikz_math_sout_def;
+
 	if (mustProvide("ct-none"))
 		macros << changetracking_none_def;
 
@@ -1430,7 +1484,10 @@ docstring const LaTeXFeatures::getTClassPreamble() const
 	list<docstring>::const_iterator cit = usedLayouts_.begin();
 	list<docstring>::const_iterator end = usedLayouts_.end();
 	for (; cit != end; ++cit)
-		tcpreamble << tclass[*cit].preamble();
+		// For InPreamble layouts, we output the preamble stuff earlier
+		// (before the layouts). See Paragraph::Private::validate.
+		if (!tclass[*cit].inpreamble)
+			tcpreamble << tclass[*cit].preamble();
 
 	cit = usedInsetLayouts_.begin();
 	end = usedInsetLayouts_.end();
