@@ -122,10 +122,14 @@ public:
 	bool hasOnlyPolyglossiaLanguages() const;
 	/// check if a language is supported only by polyglossia
 	bool hasPolyglossiaExclusiveLanguages() const;
+	/// A vector of all used languages supported only by polyglossia
+	std::vector<std::string> getPolyglossiaExclusiveLanguages() const;
+	/// A vector of all used languages supported only by babel
+	std::vector<std::string> getBabelExclusiveLanguages() const;
 	///
 	std::string getBabelLanguages() const;
 	///
-	std::map<std::string, std::string> getPolyglossiaLanguages() const;
+	std::set<std::string> getPolyglossiaLanguages() const;
 	///
 	std::set<std::string> getEncodingSet(std::string const & doc_encoding) const;
 	///
@@ -152,6 +156,10 @@ public:
 	bool inFloat() const { return in_float_; }
 	/// are we in a float?
 	void inFloat(bool const b) { in_float_ = b; }
+	/// are we in a deleted inset?
+	bool inDeletedInset() const { return in_deleted_inset_; }
+	/// are we in a deleted inset?
+	void inDeletedInset(bool const b) { in_deleted_inset_ = b; }
 	/// Runparams that will be used for exporting this file.
 	OutputParams const & runparams() const { return runparams_; }
 	/// Resolve alternatives like "esint|amsmath|wasysym"
@@ -205,6 +213,8 @@ private:
 	///
 	bool in_float_;
 	///
+	bool in_deleted_inset_;
+	///
 	docstring htmltitle_;
 };
 
