@@ -104,17 +104,25 @@ public:
 		FontInfo font;
 		FontInfo labelfont;
 		bool autoinsert;
+		bool insertcotext;
+		docstring pass_thru_chars;
+		bool is_toc_caption;
 	};
 	///
 	typedef std::map<std::string, latexarg> LaTeXArgMap;
 	///
-	LaTeXArgMap args() const;
-	///
 	LaTeXArgMap const & latexargs() const { return latexargs_; }
 	///
 	LaTeXArgMap const & postcommandargs() const { return postcommandargs_; }
 	///
 	LaTeXArgMap const & itemargs() const { return itemargs_; }
+	/// Returns latexargs() + postcommandargs() + itemargs().
+	/// But note that it returns a *copy*, not a reference, so do not do
+	/// anything like:
+	///   Layout::LaTeXArgMap::iterator it = args().begin();
+	///   Layout::LaTeXArgMap::iterator en = args().end();
+	/// Those are iterators for different containers.
+	LaTeXArgMap args() const;
 	///
 	int optArgs() const;
 	///
@@ -183,10 +191,7 @@ public:
 	}
 	/// Is this the kind of layout in which adjacent paragraphs
 	/// are handled as one group?
-	bool isParagraphGroup() const {
-	return latextype == LATEX_ENVIRONMENT
-		|| latextype == LATEX_BIB_ENVIRONMENT;
-	}
+	bool isParagraphGroup() const {	return par_group_; }
 	///
 	bool labelIsInline() const {
 		return labeltype == LABEL_STATIC
@@ -199,6 +204,12 @@ public:
 			|| labeltype == LABEL_CENTERED
 		  || labeltype == LABEL_BIBLIO;
 	}
+	///
+	bool addToToc() const { return add_to_toc_; }
+	///
+	std::string tocType() const { return toc_type_; }
+	///
+	bool isTocCaption() const { return is_toc_caption_; }
 
 	///
 	bool operator==(Layout const &) const;
@@ -275,9 +286,13 @@ public:
 	///
 	bool nextnoindent;
 	///
+	ToggleIndentation toggle_indent;
+	///
 	bool free_spacing;
 	///
 	bool pass_thru;
+	/// Individual chars to be passed verbatim
+	docstring pass_thru_chars;
 	///
 	bool parbreak_is_newline;
 	/// show this in toc
@@ -433,7 +448,7 @@ private:
 	mutable std::string defaultcssclass_;
 	/// This is the `category' for this layout. The following are
 	/// recommended basic categories: FrontMatter, BackMatter, MainText,
-	/// Section, Starred, List, Theorem.
+	/// Sectioning, Starred, List, Reasoning.
 	docstring category_;
 	/// Macro definitions needed for this layout
 	docstring preamble_;
@@ -441,6 +456,8 @@ private:
 	docstring langpreamble_;
 	/// Language and babel dependent macro definitions needed for this layout
 	docstring babelpreamble_;
+	/// Are adjacent paragraphs handled as one group?
+	bool par_group_;
 	/// Packages needed for this layout
 	std::set<std::string> requires_;
 	///
@@ -449,8 +466,15 @@ private:
 	LaTeXArgMap postcommandargs_;
 	///
 	LaTeXArgMap itemargs_;
+	///
+	bool add_to_toc_;
+	///
+	std::string toc_type_;
+	///
+	bool is_toc_caption_;
 };
 
+
 } // namespace lyx
 
 #endif
