@@ -50,6 +50,7 @@
 #include "frontends/alert.h"
 #include "frontends/Application.h"
 
+#include "support/ConsoleApplication.h"
 #include "support/lassert.h"
 #include "support/debug.h"
 #include "support/environment.h"
@@ -60,8 +61,6 @@
 #include "support/Messages.h"
 #include "support/os.h"
 #include "support/Package.h"
-#include "support/PathChanger.h"
-#include "support/Systemcall.h"
 
 #include "support/bind.h"
 #include <boost/scoped_ptr.hpp>
@@ -127,18 +126,6 @@ void showFileError(string const & error)
 			   "Please check your installation."), from_utf8(error)));
 }
 
-
-void reconfigureUserLyXDir()
-{
-	string const configure_command = package().configure_command();
-
-	lyxerr << to_utf8(_("LyX: reconfiguring user directory")) << endl;
-	PathChanger p(package().user_support());
-	Systemcall one;
-	one.startscript(Systemcall::Wait, configure_command);
-	lyxerr << "LyX: " << to_utf8(_("Done!")) << endl;
-}
-
 } // namespace anon
 
 /// The main application class private implementation.
@@ -188,8 +175,6 @@ struct LyX::Impl {
 	///
 	Movers system_movers_;
 
-	/// has this user started lyx for the first time?
-	bool first_start;
 	/// the parsed command line batch command if any
 	vector<string> batch_commands;
 
@@ -209,6 +194,27 @@ struct LyX::Impl {
 };
 
 
+/// The main application class for console mode
+class LyXConsoleApp : public ConsoleApplication
+{
+public:
+	LyXConsoleApp(LyX * lyx, int & argc, char * argv[])
+		: ConsoleApplication(lyx_package, argc, argv), lyx_(lyx),
+		  argc_(argc), argv_(argv)
+	{
+	}
+	void doExec()
+	{
+		int const exit_status = lyx_->execWithoutGui(argc_, argv_);
+		exit(exit_status);
+	}
+private:
+	LyX * lyx_;
+	int & argc_;
+	char ** argv_;
+};
+
+
 ///
 frontend::Application * theApp()
 {
@@ -301,39 +307,13 @@ int LyX::exec(int & argc, char * argv[])
 	setLocale();
 
 	if (!use_gui) {
-		// FIXME: create a ConsoleApplication
-		int exit_status = init(argc, argv);
-		if (exit_status) {
-			prepareExit();
-			return exit_status;
-		}
+		LyXConsoleApp app(this, argc, argv);
 
-		// this is correct, since return values are inverted.
-		exit_status = !loadFiles();
+		// Reestablish our defaults, as Qt overwrites them
+		// after creating app
+		setLocale();//???
 
-		if (pimpl_->batch_commands.empty() || pimpl_->buffer_list_.empty()) {
-			prepareExit();
-			return exit_status;
-		}
-
-		BufferList::iterator begin = pimpl_->buffer_list_.begin();
-
-		bool final_success = false;
-		for (BufferList::iterator I = begin; I != pimpl_->buffer_list_.end(); ++I) {
-			Buffer * buf = *I;
-			if (buf != buf->masterBuffer())
-				continue;
-			vector<string>::const_iterator bcit  = pimpl_->batch_commands.begin();
-			vector<string>::const_iterator bcend = pimpl_->batch_commands.end();
-			DispatchResult dr;
-			for (; bcit != bcend; ++bcit) {
-				LYXERR(Debug::ACTION, "Buffer::dispatch: cmd: " << *bcit);
-				buf->dispatch(*bcit, dr);
-				final_success |= !dr.error();
-			}
-		}
-		prepareExit();
-		return !final_success;
+		return app.exec();
 	}
 
 	// Let the frontend parse and remove all arguments that it knows
@@ -361,7 +341,7 @@ int LyX::exec(int & argc, char * argv[])
 
 	// FIXME
 	/* Create a CoreApplication class that will provide the main event loop
-	* and the socket callback registering. With Qt4, only QtCore
+	* and the socket callback registering. With Qt, only QtCore
 	* library would be needed.
 	* When this is done, a server_mode could be created and the following two
 	* line would be moved out from here.
@@ -424,10 +404,8 @@ void LyX::prepareExit()
 			LYXERR(Debug::INFO, "Deleting tmp dir "
 				<< package().temp_dir().absFileName());
 			if (!package().temp_dir().destroyDirectory()) {
-				docstring const msg =
-					bformat(_("Unable to remove the temporary directory %1$s"),
-					from_utf8(package().temp_dir().absFileName()));
-				Alert::warning(_("Unable to remove temporary directory"), msg);
+				LYXERR0(bformat(_("Unable to remove the temporary directory %1$s"),
+					from_utf8(package().temp_dir().absFileName())));
 			}
 		}
 	}
@@ -486,39 +464,70 @@ int LyX::init(int & argc, char * argv[])
 }
 
 
-bool LyX::loadFiles()
+int LyX::execWithoutGui(int & argc, char * argv[])
 {
-	LATTEST(!use_gui);
-	bool success = true;
+	int exit_status = init(argc, argv);
+	if (exit_status) {
+		prepareExit();
+		return exit_status;
+	}
+
+	// Used to keep track of which buffers were explicitly loaded by user request.
+	// This is necessary because master and child document buffers are loaded, even 
+	// if they were not named on the command line. We do not want to dispatch to
+	// those.
+	vector<Buffer *> command_line_buffers;
+
+	// Load the files specified on the command line
 	vector<string>::const_iterator it = pimpl_->files_to_load_.begin();
 	vector<string>::const_iterator end = pimpl_->files_to_load_.end();
-
 	for (; it != end; ++it) {
-		// get absolute path of file and add ".lyx" to
-		// the filename if necessary
+		// get absolute path of file and add ".lyx" to the filename if necessary
 		FileName fname = fileSearch(string(), os::internal_path(*it), "lyx",
-			may_not_exist);
+																may_not_exist);
 
 		if (fname.empty())
 			continue;
 
 		Buffer * buf = pimpl_->buffer_list_.newBuffer(fname.absFileName());
+		LYXERR(Debug::FILES, "Loading " << fname);
 		if (buf->loadLyXFile() == Buffer::ReadSuccess) {
 			ErrorList const & el = buf->errorList("Parse");
 			if (!el.empty())
-				for_each(el.begin(), el.end(),
-				bind(&LyX::printError, this, _1));
-		}
-		else {
+					for_each(el.begin(), el.end(),
+									 bind(&LyX::printError, this, _1));
+			command_line_buffers.push_back(buf);
+		} else {
 			pimpl_->buffer_list_.release(buf);
 			docstring const error_message =
-				bformat(_("LyX failed to load the following file: %1$s"),
-				from_utf8(fname.absFileName()));
+					bformat(_("LyX failed to load the following file: %1$s"),
+									from_utf8(fname.absFileName()));
 			lyxerr << to_utf8(error_message) << endl;
-			success = false;
+			exit_status = 1; // failed
 		}
 	}
-	return success;
+
+	if (exit_status || pimpl_->batch_commands.empty() || pimpl_->buffer_list_.empty()) {
+		prepareExit();
+		return exit_status;
+	}
+
+	// Iterate through the buffers that were specified on the command line
+	bool final_success = false;
+	vector<Buffer *>::iterator buf_it = command_line_buffers.begin();
+	for (; buf_it != command_line_buffers.end(); ++buf_it) {
+		Buffer * buf = *buf_it;
+		vector<string>::const_iterator bcit  = pimpl_->batch_commands.begin();
+		vector<string>::const_iterator bcend = pimpl_->batch_commands.end();
+		DispatchResult dr;
+		for (; bcit != bcend; ++bcit) {
+			LYXERR(Debug::ACTION, "Buffer::dispatch: cmd: " << *bcit);
+			buf->dispatch(*bcit, dr);
+			final_success |= !dr.error();
+		}
+	}
+	prepareExit();
+	return !final_success;
 }
 
 
@@ -724,7 +733,7 @@ namespace {
 		}
 	}
 }
-	
+
 void cleanDuplicateEnvVars()
 {
 	std::set<std::string> seen;
@@ -744,7 +753,9 @@ void cleanDuplicateEnvVars()
 	}
 
 	// Loop over the list of duplicated variables
-	for (std::set<std::string>::iterator dupe = dupes.begin(); dupe != dupes.end(); dupe++) {
+	std::set<std::string>::iterator dupe = dupes.begin();
+	std::set<std::string>::iterator const dend = dupes.end();
+	for (; dupe != dend; ++dupe) {
 		const char *name = (*dupe).c_str();
 		char *val = getenv(name);
 		if (val != NULL) {
@@ -760,6 +771,45 @@ void cleanDuplicateEnvVars()
 }
 #endif
 
+
+static void initTemplatePath()
+{
+	FileName const package_template_path =
+		FileName(addName(package().system_support().absFileName(), "templates"));
+
+	if (lyxrc.template_path.empty()) {
+		lyxrc.template_path = package_template_path.absFileName();
+	}
+#if defined (USE_MACOSX_PACKAGING)
+	FileName const user_template_path =
+		FileName(addName(package().user_support().absFileName(), "templates"));
+
+	if (package_template_path != FileName(lyxrc.template_path) &&
+		user_template_path != FileName(lyxrc.template_path))
+	{
+		return;
+	}
+	FileName const user_template_link =
+		FileName(addName(user_template_path.absFileName(),"SystemTemplates"));
+	if (user_template_link.isSymLink() && !equivalent(user_template_link, package_template_path)) {
+		user_template_link.removeFile();
+	}
+	if (!user_template_link.exists()) {
+		if (!package_template_path.link(user_template_link)) {
+			FileName const user_support = package().user_support();
+			if (user_support.exists() && user_support.isDirectory()) {
+				LYXERR(Debug::INIT, "Cannot create symlink " + user_template_link.absFileName());
+				lyxrc.template_path = package_template_path.absFileName();
+			}
+			return;
+		}
+		LYXERR(Debug::INIT, "Symlink \"" << user_template_link.absFileName() << "\" created.");
+	}
+	lyxrc.template_path = user_template_path.absFileName();
+#endif
+}
+
+
 bool LyX::init()
 {
 #ifdef SIGHUP
@@ -782,10 +832,7 @@ bool LyX::init()
 		lyxrc.example_path = addPath(package().system_support().absFileName(),
 					      "examples");
 	}
-	if (lyxrc.template_path.empty()) {
-		lyxrc.template_path = addPath(package().system_support().absFileName(),
-					      "templates");
-	}
+	initTemplatePath();
 
 	// init LyXDir environment variable
 	string const lyx_dir = package().lyx_dir().absFileName();
@@ -814,7 +861,7 @@ bool LyX::init()
 		return false;
 
 	// Set the PATH correctly.
-#if !defined (USE_POSIX_PACKAGING)
+#if !defined (USE_POSIX_PACKAGING) && !defined (USE_HAIKU_PACKAGING)
 	// Add the directory containing the LyX executable to the path
 	// so that LyX can find things like tex2lyx.
 	if (package().build_support().empty())
@@ -825,11 +872,13 @@ bool LyX::init()
 
 	// Check that user LyX directory is ok.
 	{
-		string const lock_file = package().user_support().absFileName() + ".lyx_configure_lock";
+		string const lock_file = package().getConfigureLockName();
 		int fd = fileLock(lock_file.c_str());
 
 		if (queryUserLyXDir(package().explicit_user_support())) {
-			reconfigureUserLyXDir();
+			package().reconfigureUserLyXDir("");
+			// Now the user directory is present on first start.
+			initTemplatePath();
 		}
 		fileUnlock(fd, lock_file.c_str());
 	}
@@ -956,27 +1005,6 @@ void emergencyCleanup()
 }
 
 
-// return true if file does not exist or is older than configure.py.
-static bool needsUpdate(string const & file)
-{
-	// We cannot initialize configure_script directly because the package
-	// is not initialized yet when static objects are constructed.
-	static FileName configure_script;
-	static bool firstrun = true;
-	if (firstrun) {
-		configure_script =
-			FileName(addName(package().system_support().absFileName(),
-				"configure.py"));
-		firstrun = false;
-	}
-
-	FileName absfile =
-		FileName(addName(package().user_support().absFileName(), file));
-	return !absfile.exists()
-		|| configure_script.lastModified() > absfile.lastModified();
-}
-
-
 bool LyX::queryUserLyXDir(bool explicit_userdir)
 {
 	// Does user directory exist?
@@ -984,10 +1012,10 @@ bool LyX::queryUserLyXDir(bool explicit_userdir)
 	if (sup.exists() && sup.isDirectory()) {
 		first_start = false;
 
-		return needsUpdate("lyxrc.defaults")
-			|| needsUpdate("lyxmodules.lst")
-			|| needsUpdate("textclass.lst")
-			|| needsUpdate("packages.lst");
+		return configFileNeedsUpdate("lyxrc.defaults")
+			|| configFileNeedsUpdate("lyxmodules.lst")
+			|| configFileNeedsUpdate("textclass.lst")
+			|| configFileNeedsUpdate("packages.lst");
 	}
 
 	first_start = !explicit_userdir;
@@ -1146,9 +1174,9 @@ int parse_version(string const &, string const &, string &)
 {
 	cout << "LyX " << lyx_version
 	       << " (" << lyx_release_date << ")" << endl;
-	cout << to_utf8(bformat(_("Built on %1$s[[date]], %2$s[[time]]"),
-		from_ascii(__DATE__), from_ascii(__TIME__))) << endl;
-
+	if (string(lyx_git_commit_hash) != "none")
+		cout << to_utf8(_("  Git commit hash "))
+		     << string(lyx_git_commit_hash).substr(0,8) << endl;
 	cout << lyx_version_info << endl;
 	exit(0);
 	return 0;
@@ -1301,7 +1329,7 @@ void LyX::easyParse(int & argc, char * argv[])
 	cmdmap["-userdir"] = parse_userdir;
 	cmdmap["-x"] = parse_execute;
 	cmdmap["--execute"] = parse_execute;
- 	cmdmap["-e"] = parse_export;
+	cmdmap["-e"] = parse_export;
 	cmdmap["--export"] = parse_export;
 	cmdmap["-E"] = parse_export_to;
 	cmdmap["--export-to"] = parse_export_to;
@@ -1354,7 +1382,7 @@ FuncStatus getStatus(FuncRequest const & action)
 }
 
 
-void dispatch(FuncRequest const & action)
+DispatchResult const & dispatch(FuncRequest const & action)
 {
 	LAPPERR(theApp());
 	return theApp()->dispatch(action);
@@ -1364,7 +1392,7 @@ void dispatch(FuncRequest const & action)
 void dispatch(FuncRequest const & action, DispatchResult & dr)
 {
 	LAPPERR(theApp());
-	return theApp()->dispatch(action, dr);
+	theApp()->dispatch(action, dr);
 }
 
 
