@@ -21,11 +21,11 @@
 
 #include <string>
 
-class BufferView;
 
 namespace lyx {
 
 namespace frontend { class Painter; }
+class BufferView;
 class Inset;
 class MacroContext;
 
@@ -117,6 +117,8 @@ public:
 	Change change_;
 	/// Whether the parent is selected as a whole
 	bool selected;
+	/// Whether the spell checker is enabled for the parent
+	bool do_spellcheck;
 	///
 	bool full_repaint;
 	/// Current background color
@@ -126,14 +128,16 @@ public:
 class TextMetricsInfo {};
 
 
-/// Generic base for temporarily changing things.
-/// The original state gets restored when the Changer is destructed.
+/// Generic base for temporarily changing things. The derived class is
+/// responsible for restoring the original state when the Changer is
+/// destructed.
 template <class Struct, class Temp = Struct>
 class Changer {
-public:
-	///
-	Changer(Struct & orig) : orig_(orig) {}
 protected:
+	///
+	Changer(Struct & orig, Temp const & save) : orig_(orig), save_(save) {}
+	///
+	Changer(Struct & orig) : orig_(orig), save_(orig) {}
 	///
 	Struct & orig_;
 	///
