@@ -764,9 +764,13 @@ void Text::breakParagraph(Cursor & cur, bool inverse_logic)
 	Layout const & layout = cpar.layout();
 
 	if (cur.lastpos() == 0 && !cpar.allowEmpty()) {
-		if (changeDepthAllowed(cur, DEC_DEPTH))
+		if (changeDepthAllowed(cur, DEC_DEPTH)) {
 			changeDepth(cur, DEC_DEPTH);
-		else {
+			pit_type const prev = depthHook(cpit, cpar.getDepth());
+			docstring const & lay = pars_[prev].layout().name();
+			if (lay != layout.name())
+				setLayout(cur, lay);
+		} else {
 			docstring const & lay = cur.paragraph().usePlainLayout()
 			    ? tclass.plainLayoutName() : tclass.defaultLayoutName();
 			if (lay != layout.name())
@@ -1064,11 +1068,6 @@ void Text::insertChar(Cursor & cur, char_type c)
 			par.eraseChar(pos - 1, cur.buffer()->params().track_changes);
 			c = 0x2014;
 			pos--;
-		} else if (par.getChar(pos - 1) == 0x2014) {
-			// convert "----" to "-"
-			par.eraseChar(pos - 1, cur.buffer()->params().track_changes);
-			c = '-';
-			pos--;
 		}
 	}
 
