@@ -123,14 +123,16 @@ public:
 	///
 	docstring asString(pit_type beg, pit_type end,
 		int options = AS_STR_NONE) const;
-	/// Appends a possibly abbreviated representation of our text
-	/// to \param os, where \param maxlen defines the maximum size
-	/// of \param os. If \param shorten is true, then we will shorten
-	/// \param os to maxlen chars and replace the final three by "...,
-	/// if \param os is longer than maxlen chars.
-	/// if \param maxlen is passed as 0, then it is ignored. (In fact,
-	/// it is reset to the maximum value for size_t.)
-	void forToc(docstring & os, size_t maxlen, bool shorten = true) const;
+
+	/// truncates str to maxlenwith an ellipsis and replaces the characters '\n'
+	/// and '\t' with spaces
+	static void shortenForOutliner(docstring & str, size_t const maxlen);
+		
+	/// Appends a possibly abbreviated representation of our text to \param os,
+	/// where \param maxlen defines the maximum size of \param os. If \param
+	/// shorten is true, then os is shortened as above
+	void forOutliner(docstring & os, size_t const maxlen,
+					 bool const shorten = true) const;
 
 	/// insert a character at cursor position
 	/// FIXME: replace Cursor with DocIterator.
@@ -188,11 +190,6 @@ public:
 	void setCursorIntern(Cursor & cur, pit_type par,
 		 pos_type pos, bool setfont = true, bool boundary = false);
 
-	///
-	void recUndo(Cursor & cur, pit_type first, pit_type last) const;
-	///
-	void recUndo(Cursor & cur, pit_type first) const;
-
 	/// Move cursor one position backwards
 	/**
 	 * Returns true if an update is needed after the move.
@@ -247,7 +244,7 @@ public:
 	///
 	bool selectWordWhenUnderCursor(Cursor & cur, word_location);
 	/// Change the case of the word at cursor position.
-	void changeCase(Cursor & cur, TextCase action);
+	void changeCase(Cursor & cur, TextCase action, bool partial);
 	/// Transposes the character at the cursor with the one before it
 	void charsTranspose(Cursor & cur);
 
@@ -293,7 +290,7 @@ public:
 	void write(std::ostream & os) const;
 	/// returns true if \end_document has not been read
 	/// insetPtr is the containing Inset
-	bool read(Lexer & lex, ErrorList & errorList, 
+	bool read(Lexer & lex, ErrorList & errorList,
 	          InsetText * insetPtr);
 
 	/// delete double spaces, leading spaces, and empty paragraphs around old cursor.
@@ -309,7 +306,7 @@ public:
 
 	/// To resolve macros properly the texts get their DocIterator.
 	/// Every macro definition is stored with its DocIterator
-	/// as well. Only those macros with a smaller iterator become 
+	/// as well. Only those macros with a smaller iterator become
 	/// visible in a paragraph.
 	DocIterator macrocontextPosition() const;
 	///
@@ -371,19 +368,15 @@ private:
 	///
 	void readParagraph(Paragraph & par, Lexer & lex, ErrorList & errorList);
 	/// Set Label Width string to all paragraphs of the same layout
-    /// and depth in a sequence.
+	/// and depth in a sequence.
 	void setLabelWidthStringToSequence(Cursor const & cur, docstring const & s);
 
 	/// Owner Inset.
 	InsetText * owner_;
 	///
 	ParagraphList pars_;
-	///
-	bool autoBreakRows_;
 	/// position of the text in the buffer.
 	DocIterator macrocontext_position_;
-	///
-	unsigned int undo_counter_;
 };
 
 
