@@ -22,7 +22,6 @@
 
 #include "Text.h"
 
-#include "Bidi.h"
 #include "Buffer.h"
 #include "buffer_funcs.h"
 #include "BufferList.h"
@@ -395,7 +394,7 @@ bool Text::cursorTop(Cursor & cur)
 bool Text::cursorBottom(Cursor & cur)
 {
 	LBUFERR(this == cur.text());
-	return setCursor(cur, cur.lastpit(), lyx::prev(paragraphs().end(), 1)->size());
+	return setCursor(cur, cur.lastpit(), prev(paragraphs().end(), 1)->size());
 }
 
 
@@ -484,7 +483,7 @@ void Text::setLabelWidthStringToSequence(Cursor const & cur,
 }
 
 
-void Text::setParagraphs(Cursor & cur, docstring arg, bool merge) 
+void Text::setParagraphs(Cursor & cur, docstring arg, bool merge)
 {
 	LBUFERR(cur.text());
 
@@ -512,7 +511,7 @@ void Text::setParagraphs(Cursor & cur, docstring arg, bool merge)
 }
 
 
-void Text::setParagraphs(Cursor & cur, ParagraphParameters const & p) 
+void Text::setParagraphs(Cursor & cur, ParagraphParameters const & p)
 {
 	LBUFERR(cur.text());
 
@@ -543,7 +542,7 @@ void Text::insertInset(Cursor & cur, Inset * inset)
 	LBUFERR(this == cur.text());
 	LBUFERR(inset);
 	cur.paragraph().insertInset(cur.pos(), inset, cur.current_font,
-		Change(cur.buffer()->params().trackChanges
+		Change(cur.buffer()->params().track_changes
 		? Change::INSERTED : Change::UNCHANGED));
 }
 
@@ -662,6 +661,7 @@ bool Text::cursorBackward(Cursor & cur)
 				cur.textRow().pos() == cur.pos() &&
 				!cur.paragraph().isLineSeparator(cur.pos() - 1) &&
 				!cur.paragraph().isNewline(cur.pos() - 1) &&
+				!cur.paragraph().isEnvSeparator(cur.pos() - 1) &&
 				!cur.paragraph().isSeparator(cur.pos() - 1)) {
 			return setCursor(cur, cur.pit(), cur.pos(), true, true);
 		}
@@ -675,8 +675,14 @@ bool Text::cursorBackward(Cursor & cur)
 	}
 
 	// move to the previous paragraph or do nothing
-	if (cur.pit() > 0)
-		return setCursor(cur, cur.pit() - 1, getPar(cur.pit() - 1).size(), true, false);
+	if (cur.pit() > 0) {
+		Paragraph & par = getPar(cur.pit() - 1);
+		pos_type lastpos = par.size();
+		if (lastpos > 0 && par.isEnvSeparator(lastpos - 1))
+			return setCursor(cur, cur.pit() - 1, lastpos - 1, true, false);
+		else
+			return setCursor(cur, cur.pit() - 1, lastpos, true, false);
+	}
 	return false;
 }
 
@@ -740,12 +746,19 @@ bool Text::cursorForward(Cursor & cur)
 			bool sep2 = cur.paragraph().isSeparator(cur.pos()+1);
 		}
 #endif
-		if (cur.textRow().endpos() == cur.pos() + 1 &&
-		    cur.textRow().endpos() != cur.lastpos() &&
-				!cur.paragraph().isNewline(cur.pos()) &&
-				!cur.paragraph().isLineSeparator(cur.pos()) &&
-				!cur.paragraph().isSeparator(cur.pos())) {
-			return setCursor(cur, cur.pit(), cur.pos() + 1, true, true);
+		if (cur.textRow().endpos() == cur.pos() + 1) {
+			if (cur.paragraph().isEnvSeparator(cur.pos()) &&
+			    cur.pos() + 1 == cur.lastpos() &&
+			    cur.pit() != cur.lastpit()) {
+				// move to next paragraph
+				return setCursor(cur, cur.pit() + 1, 0, true, false);
+			} else if (cur.textRow().endpos() != cur.lastpos() &&
+				   !cur.paragraph().isNewline(cur.pos()) &&
+				   !cur.paragraph().isEnvSeparator(cur.pos()) &&
+				   !cur.paragraph().isLineSeparator(cur.pos()) &&
+				   !cur.paragraph().isSeparator(cur.pos())) {
+				return setCursor(cur, cur.pit(), cur.pos() + 1, true, true);
+			}
 		}
 		
 		// in front of RTL boundary? Stay on this side of the boundary because:
@@ -797,7 +810,7 @@ bool Text::cursorDownParagraph(Cursor & cur)
 void Text::fixCursorAfterDelete(CursorSlice & cur, CursorSlice const & where)
 {
 	// Do nothing if cursor is not in the paragraph where the
-	// deletion occured,
+	// deletion occurred,
 	if (cur.pit() != where.pit())
 		return;
 
@@ -861,7 +874,7 @@ bool Text::deleteEmptyParagraphMechanism(Cursor & cur,
 		    && oldpar.isLineSeparator(old.pos() - 1)
 		    && !oldpar.isDeleted(old.pos() - 1)
 		    && !oldpar.isDeleted(old.pos())) {
-			oldpar.eraseChar(old.pos() - 1, cur.buffer()->params().trackChanges);
+			oldpar.eraseChar(old.pos() - 1, cur.buffer()->params().track_changes);
 // FIXME: This will not work anymore when we have multiple views of the same buffer
 // In this case, we will have to correct also the cursors held by
 // other bufferviews. It will probably be easier to do that in a more
@@ -889,9 +902,8 @@ bool Text::deleteEmptyParagraphMechanism(Cursor & cur,
 
 	if (oldpar.empty() || (oldpar.size() == 1 && oldpar.isLineSeparator(0))) {
 		// Delete old par.
-		old.recordUndo(ATOMIC_UNDO,
-			   max(old.pit() - 1, pit_type(0)),
-			   min(old.pit() + 1, old.lastpit()));
+		old.recordUndo(max(old.pit() - 1, pit_type(0)),
+		               min(old.pit() + 1, old.lastpit()));
 		ParagraphList & plist = old.text()->paragraphs();
 		bool const soa = oldpar.params().startOfAppendix();
 		plist.erase(lyx::next(plist.begin(), old.pit()));
@@ -916,7 +928,7 @@ bool Text::deleteEmptyParagraphMechanism(Cursor & cur,
 		return true;
 	}
 
-	if (oldpar.stripLeadingSpaces(cur.buffer()->params().trackChanges)) {
+	if (oldpar.stripLeadingSpaces(cur.buffer()->params().track_changes)) {
 		need_anchor_change = true;
 		// We return true here because the Paragraph contents changed and
 		// we need a redraw before further action is processed.
@@ -969,15 +981,4 @@ void Text::deleteEmptyParagraphMechanism(pit_type first, pit_type last, bool tra
 }
 
 
-void Text::recUndo(Cursor & cur, pit_type first, pit_type last) const
-{
-	cur.recordUndo(ATOMIC_UNDO, first, last);
-}
-
-
-void Text::recUndo(Cursor & cur, pit_type par) const
-{
-	cur.recordUndo(ATOMIC_UNDO, par, par);
-}
-
 } // namespace lyx
