@@ -90,7 +90,9 @@ namespace lyx {
 
 using cap::copySelection;
 using cap::cutSelection;
+using cap::cutSelectionToTemp;
 using cap::pasteFromStack;
+using cap::pasteFromTemp;
 using cap::pasteClipboardText;
 using cap::pasteClipboardGraphics;
 using cap::replaceSelection;
@@ -298,7 +300,7 @@ static bool doInsertInset(Cursor & cur, Text * text,
 
 	bool gotsel = false;
 	if (cur.selection()) {
-		cutSelection(cur, false, pastesel);
+		cutSelectionToTemp(cur, false, pastesel);
 		cur.clearSelection();
 		gotsel = true;
 	}
@@ -310,7 +312,7 @@ static bool doInsertInset(Cursor & cur, Text * text,
 	if (!gotsel || !pastesel)
 		return true;
 
-	pasteFromStack(cur, cur.buffer()->errorList("Paste"), 0);
+	pasteFromTemp(cur, cur.buffer()->errorList("Paste"));
 	cur.buffer()->errors("Paste");
 	cur.clearSelection(); // bug 393
 	cur.finishUndo();
@@ -1088,13 +1090,7 @@ void Text::dispatch(Cursor & cur, FuncRequest & cmd)
 		Paragraph const & par = pars_[pit];
 		bool lastpar = (pit == pit_type(pars_.size() - 1));
 		Paragraph const & nextpar = lastpar ? par : pars_[pit + 1];
-		pit_type prev = pit;
-		if (pit > 0) {
-			if (!pars_[pit - 1].layout().isEnvironment())
-				prev = depthHook(pit, par.getDepth());
-			else if (pars_[pit - 1].getDepth() >= par.getDepth())
-				prev = pit - 1;
-		}
+		pit_type prev = pit > 0 ? depthHook(pit, par.getDepth()) : pit;
 		if (prev < pit && cur.pos() == par.beginOfBody()
 		    && !par.size() && !par.isEnvSeparator(cur.pos())
 		    && !par.layout().isCommand()
@@ -1760,13 +1756,9 @@ void Text::dispatch(Cursor & cur, FuncRequest & cmd)
 	}
 
 	case LFUN_HREF_INSERT: {
-		// FIXME If we're actually given an argument, shouldn't
-		// we use it, whether or not we have a selection?
 		docstring content = cmd.argument();
-		if (cur.selection()) {
+		if (content.empty() && cur.selection())
 			content = cur.selectionAsString(false);
-			cutSelection(cur, true, false);
-		}
 
 		InsetCommandParams p(HYPERLINK_CODE);
 		if (!content.empty()){
