@@ -21,6 +21,8 @@
 #include "BufferParams.h"
 #include "buffer_funcs.h"
 #include "Cursor.h"
+#include "CutAndPaste.h"
+#include "ErrorList.h"
 #include "Paragraph.h"
 #include "ParagraphList.h"
 #include "Text.h"
@@ -29,10 +31,12 @@
 #include "mathed/MathData.h"
 
 #include "insets/Inset.h"
+#include "insets/InsetText.h"
 
 #include "support/debug.h"
 #include "support/gettext.h"
 #include "support/lassert.h"
+#include "support/lyxtime.h"
 
 #include <algorithm>
 #include <deque>
@@ -68,18 +72,23 @@ struct UndoElement
 	///
 	UndoElement(UndoKind kin, CursorData const & cb,
 	            StableDocIterator const & cel,
-	            pit_type fro, pit_type en, ParagraphList * pl,
-	            MathData * ar, BufferParams const & bp,
-	            bool ifb, bool lc, size_t gid) :
-	        kind(kin), cur_before(cb), cell(cel), from(fro), end(en),
-	        pars(pl), array(ar), bparams(0), isFullBuffer(ifb),
-		lyx_clean(lc), group_id(gid)
+	            pit_type fro, pit_type en, ParagraphList * pl, MathData * ar,
+	            bool lc, size_t gid) :
+		kind(kin), cur_before(cb), cell(cel), from(fro), end(en),
+		pars(pl), array(ar), bparams(0),
+		lyx_clean(lc), group_id(gid), time(current_time())
+		{
+		}
+	///
+	UndoElement(CursorData const & cb, BufferParams const & bp,
+				bool lc, size_t gid) :
+		kind(ATOMIC_UNDO), cur_before(cb), cell(), from(0), end(0),
+		pars(0), array(0), bparams(new BufferParams(bp)),
+		lyx_clean(lc), group_id(gid), time(current_time())
 	{
-		if (isFullBuffer)
-			bparams = new BufferParams(bp);
 	}
 	///
-	UndoElement(UndoElement const & ue)
+	UndoElement(UndoElement const & ue) : time(current_time())
 	{
 		kind = ue.kind;
 		cur_before = ue.cur_before;
@@ -89,16 +98,15 @@ struct UndoElement
 		end = ue.end;
 		pars = ue.pars;
 		array = ue.array;
-		bparams = ue.isFullBuffer
-			? new BufferParams(*ue.bparams) : ue.bparams;
-		isFullBuffer = ue.isFullBuffer;
+		bparams = ue.bparams
+			? new BufferParams(*ue.bparams) : 0;
 		lyx_clean = ue.lyx_clean;
 		group_id = ue.group_id;
 	}
 	///
 	~UndoElement()
 	{
-		if (isFullBuffer)
+		if (bparams)
 			delete bparams;
 	}
 	/// Which kind of operation are we recording for?
@@ -117,14 +125,14 @@ struct UndoElement
 	ParagraphList * pars;
 	/// the contents of the saved MathData (for mathed)
 	MathData * array;
-	/// Only used in case of full backups
+	/// Only used in case of params undo
 	BufferParams const * bparams;
-	/// Only used in case of full backups
-	bool isFullBuffer;
 	/// Was the buffer clean at this point?
 	bool lyx_clean;
 	/// the element's group id
 	size_t group_id;
+	/// timestamp
+	time_t time;
 private:
 	/// Protect construction
 	UndoElement();
@@ -190,7 +198,7 @@ private:
 struct Undo::Private
 {
 	Private(Buffer & buffer) : buffer_(buffer), undo_finished_(true),
-				   group_id(0), group_level(0) {}
+				   group_id_(0), group_level_(0) {}
 
 	// Do one undo/redo step
 	void doTextUndoOrRedo(CursorData & cur, UndoElementStack & stack,
@@ -204,15 +212,17 @@ struct Undo::Private
 		pit_type first_pit,
 		pit_type last_pit,
 		CursorData const & cur,
-		bool isFullBuffer,
 		UndoElementStack & stack);
 	///
 	void recordUndo(UndoKind kind,
 		DocIterator const & cell,
 		pit_type first_pit,
 		pit_type last_pit,
-		CursorData const & cur,
-		bool isFullBuffer);
+		CursorData const & cur);
+	///
+	void doRecordUndoBufferParams(CursorData const & cur, UndoElementStack & stack);
+	///
+	void recordUndoBufferParams(CursorData const & cur);
 
 	///
 	Buffer & buffer_;
@@ -225,9 +235,11 @@ struct Undo::Private
 	bool undo_finished_;
 
 	/// Current group Id.
-	size_t group_id;
+	size_t group_id_;
 	/// Current group nesting nevel.
-	size_t group_level;
+	size_t group_level_;
+	/// the position of cursor before the group was created
+	CursorData group_cur_before_;
 };
 
 
@@ -256,8 +268,8 @@ void Undo::clear()
 	d->undo_finished_ = true;
 	// We used to do that, but I believe it is better to keep
 	// groups (only used in Buffer::reload for now (JMarc)
-	//d->group_id = 0;
-	//d->group_level = 0;
+	//d->group_id_ = 0;
+	//d->group_level_ = 0;
 }
 
 
@@ -299,12 +311,11 @@ void Undo::Private::doRecordUndo(UndoKind kind,
 	DocIterator const & cell,
 	pit_type first_pit, pit_type last_pit,
 	CursorData const & cur_before,
-	bool isFullBuffer,
 	UndoElementStack & stack)
 {
-	if (!group_level) {
+	if (!group_level_) {
 		LYXERR0("There is no group open (creating one)");
-		++group_id;
+		++group_id_;
 	}
 
 	if (first_pit > last_pit)
@@ -318,22 +329,25 @@ void Undo::Private::doRecordUndo(UndoKind kind,
 	if (!undo_finished_
 	    && kind != ATOMIC_UNDO
 	    && !stack.empty()
+	    && !stack.top().bparams
 	    && samePar(stack.top().cell, cell)
 	    && stack.top().kind == kind
 	    && stack.top().from == from
-	    && stack.top().end == end) {
+	    && stack.top().end == end
+	    && stack.top().cur_after == cur_before
+	    && current_time() - stack.top().time <= 2) {
 		// reset cur_after; it will be filled correctly by endUndoGroup.
 		stack.top().cur_after = CursorData();
+		// update the timestamp of the undo element
+		stack.top().time = current_time();
 		return;
 	}
 
-	if (isFullBuffer)
-		LYXERR(Debug::UNDO, "Create full buffer undo element of group " << group_id);
-	else
-		LYXERR(Debug::UNDO, "Create undo element of group " << group_id);
+	LYXERR(Debug::UNDO, "Create undo element of group " << group_id_);
 	// create the position information of the Undo entry
-	UndoElement undo(kind, cur_before, cell, from, end, 0, 0,
-	                 buffer_.params(), isFullBuffer, buffer_.isClean(), group_id);
+	UndoElement undo(kind,
+	      group_cur_before_.empty() ? cur_before : group_cur_before_,
+	      cell, from, end, 0, 0, buffer_.isClean(), group_id_);
 
 	// fill in the real data to be saved
 	if (cell.inMathed()) {
@@ -363,14 +377,46 @@ void Undo::Private::doRecordUndo(UndoKind kind,
 void Undo::Private::recordUndo(UndoKind kind,
 			       DocIterator const & cell,
 			       pit_type first_pit, pit_type last_pit,
-			       CursorData const & cur,
-			       bool isFullBuffer)
+			       CursorData const & cur)
 {
 	LASSERT(first_pit <= cell.lastpit(), return);
 	LASSERT(last_pit <= cell.lastpit(), return);
 
 	doRecordUndo(kind, cell, first_pit, last_pit, cur,
-		isFullBuffer, undostack_);
+		undostack_);
+
+	// next time we'll try again to combine entries if possible
+	undo_finished_ = false;
+
+	// If we ran recordUndo, it means that we plan to change the buffer
+	buffer_.markDirty();
+
+	redostack_.clear();
+}
+
+
+void Undo::Private::doRecordUndoBufferParams(CursorData const & cur_before,
+                                             UndoElementStack & stack)
+{
+	if (!group_level_) {
+		LYXERR0("There is no group open (creating one)");
+		++group_id_;
+	}
+
+	LYXERR(Debug::UNDO, "Create full buffer undo element of group " << group_id_);
+	// create the position information of the Undo entry
+	UndoElement undo(group_cur_before_.empty() ? cur_before : group_cur_before_,
+                     buffer_.params(), buffer_.isClean(),
+					 group_id_);
+
+	// push the undo entry to undo stack
+	stack.push(undo);
+}
+
+
+void Undo::Private::recordUndoBufferParams(CursorData const & cur)
+{
+	doRecordUndoBufferParams(cur, undostack_);
 
 	// next time we'll try again to combine entries if possible
 	undo_finished_ = false;
@@ -379,9 +425,6 @@ void Undo::Private::recordUndo(UndoKind kind,
 	buffer_.markDirty();
 
 	redostack_.clear();
-	//lyxerr << "undostack:\n";
-	//for (size_t i = 0, n = buf.undostack().size(); i != n && i < 6; ++i)
-	//	lyxerr << "  " << i << ": " << buf.undostack()[i] << endl;
 }
 
 
@@ -396,24 +439,30 @@ void Undo::Private::doTextUndoOrRedo(CursorData & cur, UndoElementStack & stack,
 	// We will store in otherstack the part of the document under 'undo'
 	DocIterator cell_dit = undo.cell.asDocIterator(&buffer_);
 
-	LATTEST(undo.end <= cell_dit.lastpit());
-	doRecordUndo(ATOMIC_UNDO, cell_dit,
-		undo.from, cell_dit.lastpit() - undo.end, undo.cur_after,
-		undo.isFullBuffer, otherstack);
+	if (undo.bparams)
+		doRecordUndoBufferParams(undo.cur_after, otherstack);
+	else {
+		LATTEST(undo.end <= cell_dit.lastpit());
+		doRecordUndo(ATOMIC_UNDO, cell_dit,
+					 undo.from, cell_dit.lastpit() - undo.end, undo.cur_after,
+					 otherstack);
+	}
 	otherstack.top().cur_after = undo.cur_before;
 
 	// This does the actual undo/redo.
 	//LYXERR0("undo, performing: " << undo);
 	DocIterator dit = undo.cell.asDocIterator(&buffer_);
-	if (undo.isFullBuffer) {
-		LBUFERR(undo.pars);
-		// This is a full document
+	if (undo.bparams) {
+		// This is a params undo element
 		delete otherstack.top().bparams;
 		otherstack.top().bparams = new BufferParams(buffer_.params());
+		DocumentClassConstPtr olddc = buffer_.params().documentClassPtr();
 		buffer_.params() = *undo.bparams;
-		swap(buffer_.paragraphs(), *undo.pars);
-		delete undo.pars;
-		undo.pars = 0;
+		// The error list is not supposed to be helpful here.
+		ErrorList el;
+		cap::switchBetweenClasses(olddc, buffer_.params().documentClassPtr(),
+			static_cast<InsetText &>(buffer_.inset()), el);
+		LATTEST(el.empty());
 	} else if (dit.inMathed()) {
 		// We stored the full cell here as there is not much to be
 		// gained by storing just 'a few' paragraphs (most if not
@@ -510,81 +559,85 @@ bool Undo::textRedo(CursorData & cur)
 
 void Undo::beginUndoGroup()
 {
-	if (d->group_level == 0) {
+	if (d->group_level_ == 0) {
 		// create a new group
-		++d->group_id;
-		LYXERR(Debug::UNDO, "+++++++Creating new group " << d->group_id);
+		++d->group_id_;
+		LYXERR(Debug::UNDO, "+++++++Creating new group " << d->group_id_);
 	}
-	++d->group_level;
+	++d->group_level_;
+}
+
+
+void Undo::beginUndoGroup(CursorData const & cur_before)
+{
+	beginUndoGroup();
+	if (d->group_cur_before_.empty())
+		d->group_cur_before_ = cur_before;
 }
 
 
 void Undo::endUndoGroup()
 {
-	if (d->group_level == 0) {
+	if (d->group_level_ == 0) {
 		LYXERR0("There is no undo group to end here");
 		return;
 	}
-	--d->group_level;
-	if (d->group_level == 0) {
+	--d->group_level_;
+	if (d->group_level_ == 0) {
 		// real end of the group
-		LYXERR(Debug::UNDO, "-------End of group " << d->group_id);
+		d->group_cur_before_ = CursorData();
+		LYXERR(Debug::UNDO, "-------End of group " << d->group_id_);
 	}
 }
 
 
-void Undo::endUndoGroup(CursorData const & cur)
+void Undo::endUndoGroup(CursorData const & cur_after)
 {
 	endUndoGroup();
 	if (!d->undostack_.empty() && d->undostack_.top().cur_after.empty())
-		d->undostack_.top().cur_after = cur;
+		d->undostack_.top().cur_after = cur_after;
 }
 
 
-// FIXME: remove these convenience functions and make
-// Private::recordUndo public as sole interface. The code in the
-// convenience functions can move to Cursor.cpp.
-
 void Undo::recordUndo(CursorData const & cur, UndoKind kind)
 {
-	d->recordUndo(kind, cur, cur.pit(), cur.pit(), cur, false);
+	d->recordUndo(kind, cur, cur.pit(), cur.pit(), cur);
 }
 
 
-void Undo::recordUndoInset(CursorData const & cur, UndoKind kind,
-			   Inset const * inset)
+void Undo::recordUndo(CursorData const & cur, pit_type from, pit_type to)
+{
+	d->recordUndo(ATOMIC_UNDO, cur, from, to, cur);
+}
+
+
+void Undo::recordUndoInset(CursorData const & cur, Inset const * inset)
 {
 	if (!inset || inset == &cur.inset()) {
 		DocIterator c = cur;
 		c.pop_back();
-		d->recordUndo(kind, c, c.pit(), c.pit(), cur, false);
+		d->recordUndo(ATOMIC_UNDO, c, c.pit(), c.pit(), cur);
 	} else if (inset == cur.nextInset())
-		recordUndo(cur, kind);
+		recordUndo(cur);
 	else
 		LYXERR0("Inset not found, no undo stack added.");
 }
 
 
-void Undo::recordUndo(CursorData const & cur, UndoKind kind, pit_type from)
+void Undo::recordUndoBufferParams(CursorData const & cur)
 {
-	d->recordUndo(kind, cur, cur.pit(), from, cur, false);
+	d->recordUndoBufferParams(cur);
 }
 
 
-void Undo::recordUndo(CursorData const & cur, UndoKind kind,
-	pit_type from, pit_type to)
-{
-	d->recordUndo(kind, cur, from, to, cur, false);
-}
-
-
-void Undo::recordUndoFullDocument(CursorData const & cur)
+void Undo::recordUndoFullBuffer(CursorData const & cur)
 {
 	// This one may happen outside of the main undo group, so we
 	// put it in its own subgroup to avoid complaints.
 	beginUndoGroup();
 	d->recordUndo(ATOMIC_UNDO, doc_iterator_begin(&d->buffer_),
-		      0, d->buffer_.paragraphs().size() - 1, cur, true);
+		      0, d->buffer_.paragraphs().size() - 1, cur);
+	d->recordUndoBufferParams(cur);
 	endUndoGroup();
 }
 
