@@ -12,9 +12,13 @@
 
 #include "Action.h"
 
+// DispatchResult.h is needed by the windows compiler because lyx::dispatch
+// returns a DispatchResult const reference. Gcc does not complain. Weird...
+#include "DispatchResult.h"
 #include "FuncRequest.h"
 #include "FuncStatus.h"
 #include "LyX.h"
+
 #include "qt_helpers.h"
 
 #include "support/debug.h"
