@@ -71,13 +71,13 @@ FindAndReplaceWidget::FindAndReplaceWidget(GuiView & view)
 
 void FindAndReplaceWidget::dockLocationChanged(Qt::DockWidgetArea area)
 {
-       if (area == Qt::RightDockWidgetArea || area == Qt::LeftDockWidgetArea) {
-               dynamicLayoutBasic_->setDirection(QBoxLayout::TopToBottom);
-               dynamicLayoutAdvanced_->setDirection(QBoxLayout::TopToBottom);
-       } else {
-               dynamicLayoutBasic_->setDirection(QBoxLayout::LeftToRight);
-               dynamicLayoutAdvanced_->setDirection(QBoxLayout::LeftToRight);
-       }
+	if (area == Qt::RightDockWidgetArea || area == Qt::LeftDockWidgetArea) {
+		dynamicLayoutBasic_->setDirection(QBoxLayout::TopToBottom);
+		dynamicLayoutAdvanced_->setDirection(QBoxLayout::TopToBottom);
+	} else {
+		dynamicLayoutBasic_->setDirection(QBoxLayout::LeftToRight);
+		dynamicLayoutAdvanced_->setDirection(QBoxLayout::LeftToRight);
+	}
 }
 
 
@@ -110,8 +110,8 @@ bool FindAndReplaceWidget::eventFilter(QObject * obj, QEvent * event)
 		// back to how it was
 		searchbackCB->setChecked(searchback);
 		return true;
-		break;
-		}
+	}
+
 	case Qt::Key_Tab:
 		if (e->modifiers() == Qt::NoModifier) {
 			if (obj == find_work_area_){
@@ -144,14 +144,15 @@ bool FindAndReplaceWidget::eventFilter(QObject * obj, QEvent * event)
 }
 
 
-static vector<string> const & allManualsFiles() 
+static vector<string> const & allManualsFiles()
 {
-	static vector<string> v;
 	static const char * files[] = {
 		"Intro", "UserGuide", "Tutorial", "Additional",
 		"EmbeddedObjects", "Math", "Customization", "Shortcuts",
 		"LFUNs", "LaTeXConfig"
 	};
+
+	static vector<string> v;
 	if (v.empty()) {
 		FileName fname;
 		for (size_t i = 0; i < sizeof(files) / sizeof(files[0]); ++i) {
@@ -159,6 +160,7 @@ static vector<string> const & allManualsFiles()
 			v.push_back(fname.absFileName());
 		}
 	}
+
 	return v;
 }
 
@@ -167,7 +169,7 @@ static vector<string> const & allManualsFiles()
  **
  ** Return true if restarted from master-document buffer.
  **/
-static bool nextDocumentBuffer(Buffer * & buf) 
+static bool nextDocumentBuffer(Buffer * & buf)
 {
 	ListOfBuffers const children = buf->allRelatives();
 	LYXERR(Debug::FIND, "children.size()=" << children.size());
@@ -188,7 +190,7 @@ static bool nextDocumentBuffer(Buffer * & buf)
  **
  ** Return true if restarted from last child buffer.
  **/
-static bool prevDocumentBuffer(Buffer * & buf) 
+static bool prevDocumentBuffer(Buffer * & buf)
 {
 	ListOfBuffers const children = buf->allRelatives();
 	LYXERR(Debug::FIND, "children.size()=" << children.size());
@@ -287,7 +289,7 @@ docstring getQuestionString(FindAndReplaceOptions const & opt)
 	docstring message = opt.forward ?
 		bformat(_("%1$s: the end was reached while searching forward.\n"
 			  "Continue searching from the beginning?"),
-			scope) : 
+			scope) :
 		bformat(_("%1$s: the beginning was reached while searching backward.\n"
 			  "Continue searching from the end?"),
 			scope);
@@ -502,7 +504,7 @@ void FindAndReplaceWidget::hideDialog()
 }
 
 
-void FindAndReplaceWidget::on_findNextPB_clicked() 
+void FindAndReplaceWidget::on_findNextPB_clicked()
 {
 	findAndReplace(searchbackCB->isChecked(), false);
 	find_work_area_->setFocus();
@@ -587,7 +589,7 @@ FindAndReplace::FindAndReplace(GuiView & parent,
 	setFocusProxy(widget_);
 
 	connect(this, SIGNAL(dockLocationChanged(Qt::DockWidgetArea)),
-               widget_, SLOT(dockLocationChanged(Qt::DockWidgetArea)));
+	        widget_, SLOT(dockLocationChanged(Qt::DockWidgetArea)));
 }
 
 
@@ -617,7 +619,7 @@ void FindAndReplaceWidget::updateGUI()
 Dialog * createGuiSearchAdv(GuiView & lv)
 {
 	FindAndReplace * gui = new FindAndReplace(lv, Qt::RightDockWidgetArea);
-#ifdef Q_WS_MACX
+#ifdef Q_OS_MAC
 	// On Mac show and floating
 	gui->setFloating(true);
 #endif
