@@ -16,6 +16,8 @@
 
 #include "ui_DelimiterUi.h"
 
+#include "support/docstring.h"
+
 class QListWidgetItem;
 
 namespace lyx {
@@ -40,6 +42,7 @@ public Q_SLOTS:
 	void on_rightLW_currentRowChanged(int);
 	void on_matchCB_stateChanged(int);
 	void on_insertPB_clicked();
+	void on_swapPB_clicked();
 	void on_sizeCO_activated(int);
 
 private:
@@ -49,7 +52,7 @@ private:
 	void updateTeXCode(int size);
 
 	/// TeX code that will be inserted.
-	QString tex_code_;
+	docstring tex_code_;
 };
 
 } // namespace frontend
