@@ -14,6 +14,7 @@
 
 #include "GuiDialog.h"
 #include "ui_RefUi.h"
+#include "FancyLineEdit.h"
 
 #include "insets/InsetCommandParams.h"
 
@@ -39,11 +40,12 @@ private Q_SLOTS:
 	void changed_adaptor();
 	void gotoClicked();
 	void filterLabels();
+	void resetFilter();
 	void refHighlighted(QTreeWidgetItem *);
 	void selectionChanged();
+	void refTextChanged(QString const &);
 	void refSelected(QTreeWidgetItem *);
 	void sortToggled();
-	void caseSensitiveToggled();
 	void groupToggled();
 	void updateClicked();
 	void resetDialog();
@@ -93,6 +95,9 @@ private:
 	///
 	InsetCommandParams params_;
 
+	/// contains the search box
+	FancyLineEdit * filter_;
+
 	/// went to a reference ?
 	bool at_ref_;
 	/// the last reference entered or examined
