@@ -199,7 +199,7 @@ void GuiTabular::on_interlinespaceCO_activated(int index)
 }
 
 
-void GuiTabular::checkEnabled()
+void GuiTabular::enableWidgets() const
 {
 	// if there is a LaTeX argument, the width and alignment will be overwritten
 	// therefore disable them in this case
@@ -324,7 +324,12 @@ void GuiTabular::checkEnabled()
 	// Vertical lines cannot be set in formal tables
 	borders->setLeftEnabled(!booktabsRB->isChecked());
 	borders->setRightEnabled(!booktabsRB->isChecked());
+}
 
+
+void GuiTabular::checkEnabled()
+{
+	enableWidgets();
 	changed();
 }
 
@@ -442,8 +447,7 @@ void GuiTabular::setTableAlignment(string & param_str) const
 
 docstring GuiTabular::dialogToParams() const
 {
-	// FIXME: We should use Tabular directly.
-	string param_str = "tabular from-dialog";
+	string param_str = "tabular";
 
 	// table width
 	string tabwidth = widgetsToLength(tabularWidthED, tabularWidthUnitLC);
@@ -750,7 +754,8 @@ void GuiTabular::paramsToDialog(Inset const * inset)
 	// Set width and alignment
 
 	Length const tabwidth = tabular.tabularWidth();
-	if (tabwidth.zero())
+	if (tabwidth.zero()
+	    && !(tabularWidthED->hasFocus() && tabularWidthED->text() == "0"))
 		tabularWidthED->clear();
 	else
 		lengthToWidgets(tabularWidthED, tabularWidthUnitLC,
@@ -768,7 +773,8 @@ void GuiTabular::paramsToDialog(Inset const * inset)
 		pwidth = getColumnPWidth(tabular, cell);
 	}
 	string colwidth;
-	if (pwidth.zero())
+	if (pwidth.zero()
+	    && !(columnWidthED->hasFocus() && columnWidthED->text() == "0"))
 		columnWidthED->clear();
 	else {
 		colwidth = pwidth.asString();
@@ -779,7 +785,8 @@ void GuiTabular::paramsToDialog(Inset const * inset)
 	if (multirow)
 		mroffset = getMROffset(tabular, cell);
 	string offset;
-	if (mroffset.zero())
+	if (mroffset.zero()
+	    && !(multirowOffsetED->hasFocus() && multirowOffsetED->text() == "0"))
 		multirowOffsetED->clear();
 	else {
 		offset = mroffset.asString();
@@ -1016,10 +1023,54 @@ void GuiTabular::paramsToDialog(Inset const * inset)
 }
 
 
+bool GuiTabular::checkWidgets(bool readonly) const
+{
+	tabularRowED->setReadOnly(readonly);
+	tabularColumnED->setReadOnly(readonly);
+	tabularWidthED->setReadOnly(readonly);
+	specialAlignmentED->setReadOnly(readonly);
+	columnWidthED->setReadOnly(readonly);
+	multirowOffsetED->setReadOnly(readonly);
+	decimalPointED->setReadOnly(readonly);
+
+	if (readonly) {
+		multicolumnCB->setEnabled(false);
+		multirowCB->setEnabled(false);
+		rotateCellCB->setEnabled(false);
+		rotateCellAngleSB->setEnabled(false);
+		rotateTabularCB->setEnabled(false);
+		rotateTabularAngleSB->setEnabled(false);
+		longTabularCB->setEnabled(false);
+		borders->setEnabled(false);
+		tabularWidthUnitLC->setEnabled(false);
+		columnWidthUnitLC->setEnabled(false);
+		multirowOffsetUnitLC->setEnabled(false);
+		setBordersGB->setEnabled(false);
+		allBordersGB->setEnabled(false);
+		borderStyleGB->setEnabled(false);
+		booktabsRB->setEnabled(false);
+		topspaceCO->setEnabled(false);
+		topspaceUnitLC->setEnabled(false);
+		bottomspaceCO->setEnabled(false);
+		bottomspaceUnitLC->setEnabled(false);
+		interlinespaceCO->setEnabled(false);
+		interlinespaceUnitLC->setEnabled(false);
+		hAlignCO->setEnabled(false);
+		vAlignCO->setEnabled(false);
+		TableAlignCO->setEnabled(false);
+		longtableGB->setEnabled(false);
+		alignmentGB->setEnabled(false);
+	} else
+		enableWidgets();
+
+	return InsetParamsWidget::checkWidgets();
+}
+
+
 bool GuiTabular::funcEnabled(Tabular::Feature f) const
 {
-	string cmd = "tabular " + featureAsString(f);
-	return getStatus(FuncRequest(LFUN_INSET_MODIFY, cmd)).enabled();
+	FuncRequest r(LFUN_INSET_MODIFY, "tabular for-dialog" + featureAsString(f));
+	return getStatus(r).enabled();
 }
 
 
