@@ -92,8 +92,7 @@ public:
 	bool isRestored() const;
 
 	/// Refresh the contents of the bar.
-	void update(bool in_math, bool in_table, bool review,
-		bool in_mathmacrotemplate, bool in_ipa);
+	void update(int context = 0);
 
 	///
 	void toggle();
