@@ -53,7 +53,10 @@ GuiVSpace::GuiVSpace(QWidget * parent) : InsetParamsWidget(parent)
 	connect(spacingCO, SIGNAL(activated(int)),
 		this, SLOT(enableCustom(int)));
 
-	valueLE->setValidator(unsignedGlueLengthValidator(valueLE));
+	// Set up a signed glue length validator
+	LengthValidator * v = new LengthValidator(valueLE);
+	v->setBottom(GlueLength());
+	valueLE->setValidator(v);
 
 	// initialize the length validator
 	addCheckedWidget(valueLE, valueL);
@@ -146,6 +149,25 @@ void GuiVSpace::paramsToDialog(Inset const * inset)
 	enableCustom(spacingCO->currentIndex());
 }
 
+
+bool GuiVSpace::checkWidgets(bool readonly) const
+{
+	valueLE->setReadOnly(readonly);
+	keepCB->setEnabled(!readonly);
+
+	if (readonly) {
+		spacingCO->setEnabled(false);
+		unitCO->setEnabled(false);
+	} else {
+		bool const enable = (spacingCO->currentIndex() == 5);
+		valueLE->setEnabled(enable);
+		valueL->setEnabled(enable);
+		unitCO->setEnabled(enable);
+	}
+
+	return InsetParamsWidget::checkWidgets();
+}
+
 } // namespace frontend
 } // namespace lyx
 
