@@ -148,7 +148,12 @@ void ViewSourceWidget::contentsChanged()
 void ViewSourceWidget::setViewFormat(int const index)
 {
 	outputFormatCO->setCurrentIndex(index);
-	view_format_ = outputFormatCO->itemData(index).toString();
+	string format = fromqstr(outputFormatCO->itemData(index).toString());
+	if (view_format_ != format) {
+		view_format_ = format;
+		// emit signal
+		formatChanged();
+	}
 }
 
 
@@ -184,8 +189,6 @@ void ViewSourceWidget::realUpdateView()
 	// we will try to preserve this
 	int const h_scroll = viewSourceTV->horizontalScrollBar()->value();
 
-	string const format = fromqstr(view_format_);
-
 	Buffer::OutputWhat output = Buffer::CurrentParagraph;
 	if (contentsCO->currentIndex() == 1)
 		output = Buffer::FullSource;
@@ -195,7 +198,8 @@ void ViewSourceWidget::realUpdateView()
 		output = Buffer::OnlyBody;
 
 	docstring content;
-	getContent(bv_, output, content, format, masterPerspectiveCB->isChecked());
+	getContent(bv_, output, content, view_format_,
+	           masterPerspectiveCB->isChecked());
 	QString old = document_->toPlainText();
 	QString qcontent = toqstr(content);
 #ifdef DEVEL_VERSION
@@ -219,14 +223,9 @@ void ViewSourceWidget::realUpdateView()
 	if (changed && !texrow_.get()) {
 		// position-to-row is unavailable
 		// we jump to the first modification
-		const QChar * oc = old.constData();
-		const QChar * nc = qcontent.constData();
+		int length = min(old.length(), qcontent.length());
 		int pos = 0;
-		while (*oc != '\0' && *nc != '\0' && *oc == *nc) {
-			++oc;
-			++nc;
-			++pos;
-		}
+		for (; pos < length && old.at(pos) == qcontent.at(pos); ++pos) {}
 		QTextCursor c = QTextCursor(viewSourceTV->document());
 		//get some space below the cursor
 		c.setPosition(pos);
@@ -305,6 +304,16 @@ void ViewSourceWidget::realUpdateView()
 }
 
 
+docstring ViewSourceWidget::currentFormatName(BufferView const * bv) const
+{
+	// Compute the actual format used
+	string const format = !bv ? ""
+		: flavor2format(bv->buffer().params().getOutputFlavor(view_format_));
+	Format const * f = formats.getFormat(format.empty() ? view_format_ : format);
+	return from_utf8(f ? f->prettyname() : view_format_);
+}
+
+
 // only used in DEVEL_MODE for debugging
 // need a proper LFUN if we want to implement it in release mode
 void ViewSourceWidget::gotoCursor()
@@ -340,9 +349,8 @@ void ViewSourceWidget::updateDefaultFormat()
 		} 
 
 		QString const pretty = qt_(fmt->prettyname());
-		QString const qformat = toqstr(format);
-		outputFormatCO->addItem(pretty, QVariant(qformat));
-		if (qformat == view_format_)
+		outputFormatCO->addItem(pretty, QVariant(toqstr(format)));
+		if (format == view_format_)
 		   index = outputFormatCO->count() -1;
 	}
 	setViewFormat(index);
@@ -366,7 +374,7 @@ void ViewSourceWidget::resizeEvent (QResizeEvent * event)
 void ViewSourceWidget::saveSession(QString const & session_key) const
 {
 	QSettings settings;
-	settings.setValue(session_key + "/output", view_format_);
+	settings.setValue(session_key + "/output", toqstr(view_format_));
 	settings.setValue(session_key + "/contents", contentsCO->currentIndex());
 	settings.setValue(session_key + "/autoupdate", autoUpdateCB->isChecked());
 	settings.setValue(session_key + "/masterview",
@@ -377,7 +385,8 @@ void ViewSourceWidget::saveSession(QString const & session_key) const
 void ViewSourceWidget::restoreSession(QString const & session_key)
 {
 	QSettings settings;
-    view_format_ = settings.value(session_key + "/output", 0).toString();
+	view_format_ = fromqstr(settings.value(session_key + "/output", 0)
+	                        .toString());
 	contentsCO->setCurrentIndex(settings
 								.value(session_key + "/contents", 0)
 								.toInt());
@@ -395,10 +404,11 @@ void ViewSourceWidget::restoreSession(QString const & session_key)
 
 GuiViewSource::GuiViewSource(GuiView & parent,
 		Qt::DockWidgetArea area, Qt::WindowFlags flags)
-	: DockView(parent, "view-source", qt_("LaTeX Source"), area, flags)
+	: DockView(parent, "view-source", qt_("Code Preview"), area, flags)
 {
 	widget_ = new ViewSourceWidget;
 	setWidget(widget_);
+	connect(widget_, SIGNAL(formatChanged()), this, SLOT(updateTitle()));
 }
 
 
@@ -415,6 +425,7 @@ void GuiViewSource::updateView()
 		widget_->updateView();
 	}
 	widget_->masterPerspectiveCB->setEnabled(buffer().parent());
+	updateTitle();
 }
 
 
@@ -430,24 +441,19 @@ void GuiViewSource::enableView(bool enable)
 
 bool GuiViewSource::initialiseParams(string const & /*source*/)
 {
-	setWindowTitle(title());
+	updateTitle();
 	return true;
 }
 
 
-QString GuiViewSource::title() const
+void GuiViewSource::updateTitle()
 {
-	switch (docType()) {
-		case LATEX:
-			//FIXME: this is shown for LyXHTML source, LyX source, etc.
-			return qt_("LaTeX Source");
-		case DOCBOOK:
-			return qt_("DocBook Source");
-		case LITERATE:
-			return qt_("Literate Source");
-	}
-	LATTEST(false);
-	return QString();
+	docstring const format = widget_->currentFormatName(bufferview());
+	QString const title = format.empty() ? qt_("Code Preview")
+		: qt_("%1[[preview format name]] Preview")
+		  .arg(toqstr(translateIfPossible(format)));
+	setTitle(title);
+	setWindowTitle(title);
 }
 
 
