@@ -64,6 +64,11 @@ public Q_SLOTS:
 	void contentsChanged();
 	///
 	void gotoCursor();
+	/// Name of the current format. Empty if none.
+	docstring currentFormatName(BufferView const * bv) const;
+
+Q_SIGNALS:
+	void formatChanged() const;
 
 private Q_SLOTS:
 	/// update content
@@ -80,7 +85,7 @@ private:
 	/// LaTeX syntax highlighter
 	LaTeXHighlighter * highlighter_;
 	///
-	QString view_format_;
+	std::string view_format_;
 	///
 	QTimer * update_timer_;
 	/// TexRow information from the last source view. If TexRow is unavailable
@@ -116,8 +121,9 @@ public:
 	bool wantInitialFocus() const { return false; }
 	///@}
 
+private Q_SLOTS:
 	/// The title displayed by the dialog reflects source type.
-	QString title() const;
+	void updateTitle();
 
 private:
 	/// The encapsulated widget.
