@@ -47,7 +47,6 @@
 #include "support/convert.h"
 #include "support/debug.h"
 #include "support/gettext.h"
-#include "support/FileName.h"
 #include "support/lassert.h"
 #include "support/TempFile.h"
 
@@ -246,11 +245,12 @@ SyntheticMouseEvent::SyntheticMouseEvent()
 
 
 GuiWorkArea::Private::Private(GuiWorkArea * parent)
-: p(parent), screen_(0), buffer_view_(0), read_only_(false), lyx_view_(0),
-cursor_visible_(false), cursor_(0),
-need_resize_(false), schedule_redraw_(false), preedit_lines_(1),
-pixel_ratio_(1.0),
-completer_(new GuiCompleter(p, p)), dialog_mode_(false)
+: p(parent), screen_(0), buffer_view_(0), lyx_view_(0),
+  cursor_visible_(false), cursor_(0),
+  need_resize_(false), schedule_redraw_(false), preedit_lines_(1),
+  pixel_ratio_(1.0),
+  completer_(new GuiCompleter(p, p)), dialog_mode_(false),
+  read_only_(false), clean_(true)
 {
 }
 
@@ -504,6 +504,14 @@ void GuiWorkArea::redraw(bool update_metrics)
 }
 
 
+// Keep in sync with GuiWorkArea::processKeySym below
+bool GuiWorkArea::queryKeySym(KeySymbol const & key, KeyModifier mod) const
+{
+	return guiApp->queryKeySym(key, mod);
+}
+
+
+// Keep in sync with GuiWorkArea::queryKeySym above
 void GuiWorkArea::processKeySym(KeySymbol const & key, KeyModifier mod)
 {
 	if (d->lyx_view_->isFullScreen() && d->lyx_view_->menuBar()->isVisible()
@@ -723,6 +731,12 @@ bool GuiWorkArea::event(QEvent * e)
 		return true;
 	}
 
+	case QEvent::ShortcutOverride:
+		// keyPressEvent is ShortcutOverride-aware and only accepts the event in
+		// this case
+		keyPressEvent(static_cast<QKeyEvent *>(e));
+		return e->isAccepted();
+
 	case QEvent::KeyPress: {
 		// We catch this event in order to catch the Tab or Shift+Tab key press
 		// which are otherwise reserved to focus switching between controls
@@ -1037,6 +1051,10 @@ void GuiWorkArea::generateSyntheticMouseEvent()
 
 void GuiWorkArea::keyPressEvent(QKeyEvent * ev)
 {
+	// this is also called for ShortcutOverride events. In this case, one must
+	// not act but simply accept the event explicitly.
+	bool const act = (ev->type() != QEvent::ShortcutOverride);
+
 	// Do not process here some keys if dialog_mode_ is set
 	if (d->dialog_mode_
 		&& (ev->modifiers() == Qt::NoModifier
@@ -1054,7 +1072,8 @@ void GuiWorkArea::keyPressEvent(QKeyEvent * ev)
 		switch (ev->key()) {
 		case Qt::Key_Enter:
 		case Qt::Key_Return:
-			d->completer_->activate();
+			if (act)
+				d->completer_->activate();
 			ev->accept();
 			return;
 		}
@@ -1064,7 +1083,9 @@ void GuiWorkArea::keyPressEvent(QKeyEvent * ev)
 	// (the auto repeated events come too fast)
 	// it looks like this is only needed on X11
 #if defined(Q_WS_X11) || defined(QPA_XCB)
-	if (qApp->hasPendingEvents() && ev->isAutoRepeat()) {
+	// FIXME: this is a weird way to implement event compression. Also, this is
+	// broken with IBus.
+	if (act && qApp->hasPendingEvents() && ev->isAutoRepeat()) {
 		switch (ev->key()) {
 		case Qt::Key_PageDown:
 		case Qt::Key_PageUp:
@@ -1079,7 +1100,7 @@ void GuiWorkArea::keyPressEvent(QKeyEvent * ev)
 	}
 #endif
 
-	KeyModifier m = q_key_state(ev->modifiers());
+	KeyModifier const m = q_key_state(ev->modifiers());
 
 	std::string str;
 	if (m & ShiftModifier)
@@ -1090,16 +1111,20 @@ void GuiWorkArea::keyPressEvent(QKeyEvent * ev)
 		str += "Alt-";
 	if (m & MetaModifier)
 		str += "Meta-";
-	
-	LYXERR(Debug::KEY, " count: " << ev->count() << " text: " << ev->text()
-		<< " isAutoRepeat: " << ev->isAutoRepeat() << " key: " << ev->key()
-		<< " keyState: " << str);
+
+	if (act)
+		LYXERR(Debug::KEY, " count: " << ev->count() << " text: " << ev->text()
+		       << " isAutoRepeat: " << ev->isAutoRepeat() << " key: " << ev->key()
+		       << " keyState: " << str);
 
 	KeySymbol sym;
 	setKeySymbol(&sym, ev);
 	if (sym.isOK()) {
-		processKeySym(sym, q_key_state(ev->modifiers()));
-		ev->accept();
+		if (act) {
+			processKeySym(sym, m);
+			ev->accept();
+		} else
+			ev->setAccepted(queryKeySym(sym, m));
 	} else {
 		ev->ignore();
 	}
@@ -1249,6 +1274,7 @@ void GuiWorkArea::inputMethodEvent(QInputMethodEvent * e)
 	GuiPainter pain(d->screen_, pixelRatio());
 	d->buffer_view_->updateMetrics();
 	d->buffer_view_->draw(pain);
+	// FIXME: shall we use real_current_font here? (see #10478)
 	FontInfo font = d->buffer_view_->cursor().getFont().fontInfo();
 	FontMetrics const & fm = theFontMetrics(font);
 	int height = fm.maxHeight();
@@ -1373,32 +1399,13 @@ QVariant GuiWorkArea::inputMethodQuery(Qt::InputMethodQuery query) const
 
 void GuiWorkArea::updateWindowTitle()
 {
-	docstring maximize_title;
-	docstring minimize_title;
-
-	Buffer const & buf = d->buffer_view_->buffer();
-	FileName const file_name = buf.fileName();
-	if (!file_name.empty()) {
-		maximize_title = file_name.displayName(130);
-		minimize_title = from_utf8(file_name.onlyFileName());
-		if (buf.lyxvc().inUse()) {
-			if (buf.lyxvc().locking())
-				maximize_title +=  _(" (version control, locking)");
-			else
-				maximize_title +=  _(" (version control)");
-		}
-		if (!buf.isClean()) {
-			maximize_title += _(" (changed)");
-			minimize_title += char_type('*');
-		}
-		if (buf.isReadonly())
-			maximize_title += _(" (read only)");
-	}
-
-	QString const new_title = toqstr(maximize_title);
-	if (new_title != windowTitle()) {
-		QWidget::setWindowTitle(new_title);
-		QWidget::setWindowIconText(toqstr(minimize_title));
+	Buffer const & buf = bufferView().buffer();
+	if (buf.fileName() != d->file_name_ || buf.isReadonly() != d->read_only_
+	    || buf.lyxvc().vcstatus() != d->vc_status_ || buf.isClean() != d->clean_) {
+		d->file_name_ = buf.fileName();
+		d->read_only_ = buf.isReadonly();
+		d->vc_status_ = buf.lyxvc().vcstatus();
+		d->clean_ = buf.isClean();
 		titleChanged(this);
 	}
 }
