@@ -12,6 +12,8 @@
 #ifndef TOCMODEL_H
 #define TOCMODEL_H
 
+#include "support/shared_ptr.h"
+
 #include <QHash>
 #include <QSortFilterProxyModel>
 
@@ -32,11 +34,14 @@ class TocTypeModel;
 /// There is one TocModel per list in the TocBackend.
 class TocModel
 {
+	/// noncopyable
+	TocModel(TocModel const &);
+	void operator=(TocModel const &);
 public:
 	///
 	TocModel(QObject * parent);
 	///
-	void reset(Toc const & toc);
+	void reset(shared_ptr<Toc const>);
 	///
 	void reset();
 	///
@@ -68,7 +73,7 @@ private:
 	///
 	bool is_sorted_;
 	///
-	Toc const * toc_;
+	shared_ptr<Toc const> toc_;
 	///
 	int maxdepth_;
 	///
