@@ -12,6 +12,7 @@
 
 #include "PreviewImage.h"
 
+#include "Buffer.h"
 #include "Dimension.h"
 #include "GraphicsImage.h"
 #include "GraphicsLoader.h"
@@ -85,7 +86,7 @@ Dimension PreviewImage::dim() const
 	if (!image)
 		return dim;
 
-	dim.asc = int(pimpl_->ascent_frac_ * double(image->height()));
+	dim.asc = int(pimpl_->ascent_frac_ * double(image->height()) + 0.5);
 	dim.des = image->height() - dim.asc;
 	dim.wid = image->width();
 	return dim;
@@ -105,13 +106,18 @@ PreviewImage::Impl::Impl(PreviewImage & p, PreviewLoader & l,
 	: parent_(p), ploader_(l), iloader_(bf),
 	  snippet_(s), ascent_frac_(af)
 {
+	iloader_.setDisplayPixelRatio(l.displayPixelRatio());
 	iloader_.connect(bind(&Impl::statusChanged, this));
 }
 
 
 PreviewImage::Impl::~Impl()
 {
-	iloader_.filename().removeFile();
+	// If these images are generated for a clone, then that may be
+	// because we are previewing. We therefore do not want to delete
+	// them when this Buffer is destroyed.
+	if (!ploader_.buffer().isClone())
+		iloader_.filename().removeFile();
 }
 
 
