@@ -344,9 +344,11 @@ public:
 	// true for InsetTabular & InsetText
 	virtual bool isActive() const { return nargs() > 0; }
 	/// can we click at the specified position ?
-	virtual bool clickable(int, int) const { return false; }
+	virtual bool clickable(BufferView const &, int, int) const { return false; }
 	/// Move one cell backwards
 	virtual bool allowsCaptionVariation(std::string const &) const { return false; }
+	// true for insets that have a table structure (InsetMathGrid, InsetTabular)
+	virtual bool isTable() const { return false; }
 
 	/// does this contain text that can be change track marked in DVI?
 	virtual bool canTrackChanges() const { return false; }
