@@ -42,6 +42,8 @@ private:
 	///
 	bool neverIndent() const { return true; }
 	///
+	bool forceLocalFontSwitch() const { return true; }
+	///
 	InsetCode lyxCode() const { return CAPTION_CODE; }
 	///
 	void cursorPos(BufferView const & bv,
@@ -77,9 +79,8 @@ private:
 	docstring xhtml(XHTMLStream & os, OutputParams const & runparams) const;
 	///
 	void setCustomLabel(docstring const & label);
-	/// \param output_active : is the toc being generated for use by the
-	/// output routines?
-	void addToToc(DocIterator const & di, bool output_active) const;
+	///
+	void addToToc(DocIterator const & di, bool output_active, UpdateType utype) const;
 	/// 
 	virtual bool forcePlainLayout(idx_type = 0) const { return true; }
 	/// Captions don't accept alignment, spacing, etc.
@@ -94,6 +95,8 @@ private:
 	///
 	std::string floattype_;
 	///
+	bool is_subfloat_;
+	///
 	std::string type_;
 	///
 	docstring custom_label_;
