@@ -59,13 +59,14 @@ public:
 	///
 	void toString(odocstream &) const;
 	///
-	void forToc(docstring &, size_t) const;
+	void forOutliner(docstring &, size_t const, bool const) const;
 	///
 	void validate(LaTeXFeatures &) const {}
 	///
 	void updateBuffer(ParIterator const & it, UpdateType);
 	///
-	void addToToc(DocIterator const & di, bool output_active) const;
+	void addToToc(DocIterator const & di, bool output_active,
+				  UpdateType utype) const;
 	///
 	std::string contextMenuName() const;
 	//@}
