@@ -94,7 +94,7 @@ InsetCommand::~InsetCommand()
 
 void InsetCommand::metrics(MetricsInfo & mi, Dimension & dim) const
 {
-	button_.update(screenLabel(), editable() || clickable(0, 0));
+	button_.update(screenLabel(), editable() || clickable(*mi.base.bv, 0, 0));
 	button_.metrics(mi, dim);
 }
 
