@@ -119,8 +119,14 @@ string findTargetFormat(string const & format, OutputParams const & runparams)
 	}
 	// for HTML, we leave the known formats and otherwise convert to png
 	if (runparams.flavor == OutputParams::HTML) {
+		Format const * const f = formats.getFormat(format);
+		// Convert vector graphics to svg
+		if (f && f->vectorFormat() && theConverters().isReachable(format, "svg"))
+			return "svg";
+		// Leave the known formats alone
 		if (format == "jpg" || format == "png" || format == "gif")
 			return format;
+		// Convert everything else to png
 		return "png";
 	}
 	// If it's postscript, we always do eps.
@@ -133,7 +139,7 @@ string findTargetFormat(string const & format, OutputParams const & runparams)
 }
 
 
-void readInsetGraphics(Lexer & lex, string const & bufpath,
+void readInsetGraphics(Lexer & lex, Buffer const & buf, bool allowOrigin,
 	InsetGraphicsParams & params)
 {
 	bool finished = false;
@@ -150,7 +156,7 @@ void readInsetGraphics(Lexer & lex, string const & bufpath,
 		if (token == "\\end_inset") {
 			finished = true;
 		} else {
-			if (!params.Read(lex, token, bufpath))
+			if (!params.Read(lex, token, buf, allowOrigin))
 				lyxerr << "Unknown token, "
 				       << token
 				       << ", skipping."
@@ -203,6 +209,11 @@ void InsetGraphics::doDispatch(Cursor & cur, FuncRequest & cmd)
 	}
 
 	case LFUN_INSET_MODIFY: {
+		if (cmd.getArg(0) != "graphics") {
+			Inset::doDispatch(cur, cmd);
+			break;
+		}
+
 		InsetGraphicsParams p;
 		string2params(to_utf8(cmd.argument()), buffer(), p);
 		if (p.filename.empty()) {
@@ -240,8 +251,11 @@ bool InsetGraphics::getStatus(Cursor & cur, FuncRequest const & cmd,
 		FuncStatus & flag) const
 {
 	switch (cmd.action()) {
-	case LFUN_INSET_EDIT:
 	case LFUN_INSET_MODIFY:
+		if (cmd.getArg(0) != "graphics")
+			return Inset::getStatus(cur, cmd, flag);
+	// fall through
+	case LFUN_INSET_EDIT:
 	case LFUN_INSET_DIALOG_UPDATE:
 	case LFUN_GRAPHICS_RELOAD:
 		flag.setEnabled(true);
@@ -285,7 +299,7 @@ void InsetGraphics::read(Lexer & lex)
 {
 	lex.setContext("InsetGraphics::read");
 	//lex >> "Graphics";
-	readInsetGraphics(lex, buffer().filePath(), params_);
+	readInsetGraphics(lex, buffer(), true, params_);
 	graphic_->update(params().as_grfxParams());
 }
 
@@ -296,8 +310,11 @@ string InsetGraphics::createLatexOptions() const
 	// stream since we might have a trailing comma that we would like to remove
 	// before writing it to the output stream.
 	ostringstream options;
-	if (!params().bb.empty())
-	    options << "bb=" << rtrim(params().bb) << ',';
+	if (!params().bbox.empty())
+		options << "bb=" << params().bbox.xl.asLatexString() << ' '
+		        << params().bbox.yb.asLatexString() << ' '
+		        << params().bbox.xr.asLatexString() << ' '
+		        << params().bbox.yt.asLatexString() << ',';
 	if (params().draft)
 	    options << "draft,";
 	if (params().clip)
@@ -421,7 +438,7 @@ docstring InsetGraphics::createDocBookAttributes() const
 	if (!params().scale.empty() && !float_equal(scl, 0.0, 0.05)) {
 		if (!float_equal(scl, 100.0, 0.05))
 			options << " scale=\""
-				<< static_cast<int>( (scl) + 0.5 )
+				<< support::iround(scl)
 				<< "\" ";
 	} else {
 		if (!params().width.zero()) {
@@ -486,7 +503,7 @@ copyToDirIfNeeded(DocFileName const & file, string const & dir)
 {
 	string const file_in = file.absFileName();
 	string const only_path = onlyPath(file_in);
-	if (rtrim(onlyPath(file_in) , "/") == rtrim(dir, "/"))
+	if (rtrim(only_path, "/") == rtrim(dir, "/"))
 		return make_pair(IDENTICAL_PATHS, FileName(file_in));
 
 	string mangled = file.mangledFileName();
@@ -613,44 +630,7 @@ string InsetGraphics::prepareFile(OutputParams const & runparams) const
 	// determine the export format
 	string const tex_format = flavor2format(runparams.flavor);
 
-	// If the file is compressed and we have specified that it
-	// should not be uncompressed, then just return its name and
-	// let LaTeX do the rest!
 	if (formats.isZippedFile(params().filename)) {
-		if (params().noUnzip) {
-			// We don't know whether latex can actually handle
-			// this file, but we can't check, because that would
-			// mean to unzip the file and thereby making the
-			// noUnzip parameter meaningless.
-			LYXERR(Debug::GRAPHICS, "\tpass zipped file to LaTeX.");
-
-			FileName const bb_orig_file =
-				FileName(changeExtension(orig_file, "bb"));
-			if (runparams.nice) {
-				runparams.exportdata->addExternalFile(tex_format,
-						bb_orig_file,
-						changeExtension(output_file, "bb"));
-			} else {
-				// LaTeX needs the bounding box file in the
-				// tmp dir
-				FileName bb_file =
-					FileName(changeExtension(temp_file.absFileName(), "bb"));
-				boost::tie(status, bb_file) =
-					copyFileIfNeeded(bb_orig_file, bb_file);
-				if (status == FAILURE)
-					return orig_file;
-				runparams.exportdata->addExternalFile(tex_format,
-						bb_file);
-			}
-			runparams.exportdata->addExternalFile(tex_format,
-					source_file, output_file);
-			runparams.exportdata->addExternalFile("dvi",
-					source_file, output_file);
-			// We can't strip the extension, because we don't know
-			// the unzipped file format
-			return latex_path(output_file, EXCLUDE_EXTENSION);
-		}
-
 		FileName const unzipped_temp_file =
 			FileName(unzippedFileName(temp_file.absFileName()));
 		output_file = unzippedFileName(output_file);
@@ -757,7 +737,7 @@ void InsetGraphics::latex(otexstream & os,
 			&& params().filename.isReadableFile();
 	string message;
 	if (!file_exists) {
-		if (params().bb.empty())
+		if (params().bbox.empty())
 		    message = "bb = 0 0 200 100";
 		if (!params().draft) {
 			if (!message.empty())
@@ -893,15 +873,13 @@ string InsetGraphics::prepareHTMLFile(OutputParams const & runparams) const
 	if (params().filename.empty())
 		return string();
 
-	string const orig_file = params().filename.absFileName();
+	if (!params().filename.isReadableFile())
+		return string();
 
 	// The master buffer. This is useful when there are multiple levels
 	// of include files
 	Buffer const * masterBuffer = buffer().masterBuffer();
 
-	if (!params().filename.isReadableFile())
-		return string();
-
 	// We place all temporary files in the master buffer's temp dir.
 	// This is possible because we use mangled file names.
 	// FIXME We may want to put these files in some special temporary
@@ -917,14 +895,16 @@ string InsetGraphics::prepareHTMLFile(OutputParams const & runparams) const
 	if (status == FAILURE)
 		return string();
 
-	string output_file = onlyFileName(temp_file.absFileName());
-
 	string const from = formats.getFormatFromFile(temp_file);
-	if (from.empty())
+	if (from.empty()) {
 		LYXERR(Debug::GRAPHICS, "\tCould not get file format.");
+		return string();
+	}
 
 	string const to   = findTargetFormat(from, runparams);
 	string const ext  = formats.extension(to);
+	string const orig_file = params().filename.absFileName();
+	string output_file = onlyFileName(temp_file.absFileName());
 	LYXERR(Debug::GRAPHICS, "\t we have: from " << from << " to " << to);
 	LYXERR(Debug::GRAPHICS, "\tthe orig file is: " << orig_file);
 
@@ -984,10 +964,20 @@ docstring InsetGraphics::xhtml(XHTMLStream & xs, OutputParams const & op) const
 	// really be better to do width and height conversion, rather than to output
 	// these parameters here.
 	string imgstyle;
-	if (!params().width.zero())
-		imgstyle += "width:" + params().width.asHTMLString() + ";";
-	if (!params().height.zero())
-		imgstyle += " height:" + params().height.asHTMLString() + ";";
+	bool const havewidth  = !params().width.zero();
+	bool const haveheight = !params().height.zero();
+	if (havewidth || haveheight) {
+		if (havewidth)
+			imgstyle += "width:" + params().width.asHTMLString() + ";";
+		if (haveheight)
+			imgstyle += " height:" + params().height.asHTMLString() + ";";
+	} else if (params().scale != "100") {
+		// Note that this will not have the same effect as in LaTeX export:
+		// There, the image will be scaled from its original size. Here, the
+		// percentage will be interpreted by the browser, and the image will
+		// be scaled to a percentage of the window size.
+		imgstyle = "width:" + params().scale + "%;";
+	}
 	if (!imgstyle.empty())
 		imgstyle = "style='" + imgstyle + "' ";
 
@@ -1047,11 +1037,12 @@ void InsetGraphics::editGraphics(InsetGraphicsParams const & p) const
 }
 
 
-void InsetGraphics::addToToc(DocIterator const & cpit, bool output_active) const
+void InsetGraphics::addToToc(DocIterator const & cpit, bool output_active,
+							 UpdateType) const
 {
 	//FIXME UNICODE
 	docstring const str = from_utf8(params_.filename.onlyFileName());
-	buffer().tocBackend().toc("graphics").push_back(TocItem(cpit, 0, str, output_active));
+	buffer().tocBackend().toc("graphics")->push_back(TocItem(cpit, 0, str, output_active));
 }
 
 
@@ -1073,7 +1064,7 @@ void InsetGraphics::string2params(string const & in, Buffer const & buffer,
 	lex.setContext("InsetGraphics::string2params");
 	lex >> "graphics";
 	params = InsetGraphicsParams();
-	readInsetGraphics(lex, buffer.filePath(), params);
+	readInsetGraphics(lex, buffer, false, params);
 }
 
 
