@@ -35,6 +35,10 @@ namespace support {
 
 /// for including tex/lyx files
 class InsetInclude : public InsetCommand {
+	// Disable assignment operator, since it is not used, and cannot be
+	// implemented consistently with the copy constructor, because
+	// include_label is const.
+	InsetInclude & operator=(InsetInclude const &);
 public:
 	///
 	InsetInclude(Buffer * buf, InsetCommandParams const &);
@@ -64,6 +68,8 @@ public:
 
 	///
 	void updateCommand();
+	///
+	void write(std::ostream &) const;
 
 	/// \name Public functions inherited from Inset class
 	//@{
@@ -102,7 +108,8 @@ public:
 	///
 	void addPreview(DocIterator const &, graphics::PreviewLoader &) const;
 	///
-	void addToToc(DocIterator const & di, bool output_active) const;
+	void addToToc(DocIterator const & di, bool output_active,
+				  UpdateType utype) const;
 	///
 	void updateBuffer(ParIterator const &, UpdateType);
 	///
