@@ -45,7 +45,7 @@ using frontend::Painter;
 
 
 InsetLine::InsetLine(Buffer * buf, InsetCommandParams const & p)
-	: InsetCommand(buf, p)
+	: InsetCommand(buf, p), height_(0), offset_(0)
 {}
 
 
@@ -111,7 +111,7 @@ void InsetLine::metrics(MetricsInfo & mi, Dimension & dim) const
 	int const max_width = mi.base.textwidth;
 
 	Length const width(to_ascii(getParam("width")));
-	dim.wid = width.inPixels(max_width, fm.width(char_type('M')));
+	dim.wid = width.inPixels(mi.base);
 
 	// assure that the line inset is not outside of the window
 	// check that it doesn't exceed the outer boundary
@@ -123,11 +123,11 @@ void InsetLine::metrics(MetricsInfo & mi, Dimension & dim) const
 	dim.wid = max(minw, abs(dim.wid));
 
 	Length height = Length(to_ascii(getParam("height")));
-	height_ = height.inPixels(max_width, fm.width(char_type('M')));
+	height_ = height.inPixels(mi.base);
 
 	// get the length of the parameters in pixels
 	Length offset = Length(to_ascii(getParam("offset")));
-	offset_ = offset.inPixels(max_width, fm.width(char_type('M')));
+	offset_ = offset.inPixels(mi.base);
 
 	dim.asc = max(fm.maxAscent(), offset_ + height_);
 	dim.des = max(fm.maxDescent(), - offset_);
@@ -159,7 +159,7 @@ void InsetLine::draw(PainterInfo & pi, int x, int y) const
 		     y - offset_ - height_/2,
 		     x + dim.wid - height_/2 - 2,
 		     y - offset_ - height_/2,
-		     Line_color, Painter::line_solid, float(height_));
+		     Line_color, Painter::line_solid, height_);
 }
 
 
