@@ -138,7 +138,7 @@ void InsetPreview::draw(PainterInfo & pi, int x, int y) const
 {
 	if (previewState(pi.base.bv)) {
 		// one pixel gap in front
-		preview_->draw(pi, x + 1 + TEXT_TO_INSET_OFFSET, y);
+		preview_->draw(pi, x + 1, y);
 		setPosCache(pi, x, y);
 	} else
 		InsetText::draw(pi, x, y);
@@ -167,15 +167,12 @@ void InsetPreview::metrics(MetricsInfo & mi, Dimension & dim) const
 {
 	if (previewState(mi.base.bv)) {
 		preview_->metrics(mi, dim);
-		mi.base.textwidth += 2 * TEXT_TO_INSET_OFFSET;
 
 		dim.wid = max(dim.wid, 4);
 		dim.asc = max(dim.asc, 4);
 
 		dim.asc += TEXT_TO_INSET_OFFSET;
 		dim.des += TEXT_TO_INSET_OFFSET;
-		dim.wid += TEXT_TO_INSET_OFFSET;
-		dim.wid += TEXT_TO_INSET_OFFSET;
 		// insert a one pixel gap
 		dim.wid += 1;
 		// Cache the inset dimension.
