@@ -104,10 +104,6 @@ public:
 	///
 	void setText(docstring const &, Font const &, bool trackChanges);
 	///
-	void setAutoBreakRows(bool);
-	///
-	bool getAutoBreakRows() const { return text_.autoBreakRows_; }
-	///
 	void setDrawFrame(bool);
 	///
 	ColorCode frameColor() const;
@@ -173,9 +169,10 @@ public:
 	///
 	void toString(odocstream &) const;
 	///
-	void forToc(docstring &, size_t) const;
+	void forOutliner(docstring &, size_t const, bool const) const;
 	///
-	void addToToc(DocIterator const & di, bool output_active) const;
+	void addToToc(DocIterator const & di, bool output_active,
+				  UpdateType utype) const;
 	///
 	Inset * clone() const { return new InsetText(*this); }
 	///
@@ -204,6 +201,9 @@ public:
 	/// e.g., "Index: ".
 	/// \param numlines: the number of lines in the tooltip
 	/// \param len: length of those lines
+	/// NOTE This routine is kind of slow. It's fine to use it within the 
+	/// GUI, but definitely do not try to use it in updateBuffer or anything
+	/// of that sort.
 	docstring toolTipText(docstring prefix = empty_docstring(),
 			size_t numlines = 5, size_t len = 80) const;
 
@@ -221,7 +221,8 @@ protected:
 	///
 	docstring getCaptionHTML(OutputParams const &) const;
 	///
-	void iterateForToc(DocIterator const & cdit, bool output_active) const;
+	void iterateForToc(DocIterator const & cdit, bool output_active,
+					   UpdateType utype) const;
 private:
 	///
 	bool drawFrame_;
