@@ -21,6 +21,7 @@
 
 #include "support/debug.h"
 #include "support/docstream.h"
+#include "support/lyxlib.h"
 #include "support/textutils.h"
 
 #include <boost/scoped_ptr.hpp>
@@ -29,17 +30,18 @@
 namespace lyx {
 
 InsetMathSymbol::InsetMathSymbol(latexkeys const * l)
-	: sym_(l), h_(0), scriptable_(false)
+	: sym_(l), h_(0), kerning_(0), scriptable_(false)
 {}
 
 
 InsetMathSymbol::InsetMathSymbol(char const * name)
-	: sym_(in_word_set(from_ascii(name))), h_(0), scriptable_(false)
+	: sym_(in_word_set(from_ascii(name))), h_(0),
+	  kerning_(0), scriptable_(false)
 {}
 
 
 InsetMathSymbol::InsetMathSymbol(docstring const & name)
-	: sym_(in_word_set(name)), h_(0), scriptable_(false)
+	: sym_(in_word_set(name)), h_(0), kerning_(0), scriptable_(false)
 {}
 
 
@@ -65,9 +67,9 @@ void InsetMathSymbol::metrics(MetricsInfo & mi, Dimension & dim) const
 	bool const italic_upcase_greek = sym_->inset == "cmr" &&
 					 sym_->extra == "mathalpha" &&
 					 mi.base.fontname == "mathit";
-	docstring const font = italic_upcase_greek ? from_ascii("cmm") : sym_->inset;
-	int const em = mathed_char_width(mi.base.font, 'M');
-	FontSetChanger dummy(mi.base, font);
+	std::string const font = italic_upcase_greek ? "cmm" : sym_->inset;
+	int const em = mathed_font_em(mi.base.font);
+	FontSetChanger dummy(mi.base, from_ascii(font));
 	mathed_string_dim(mi.base.font, sym_->draw, dim);
 	docstring::const_reverse_iterator rit = sym_->draw.rbegin();
 	kerning_ = mathed_char_kerning(mi.base.font, *rit);
@@ -79,9 +81,9 @@ void InsetMathSymbol::metrics(MetricsInfo & mi, Dimension & dim) const
 	}
 	// seperate things a bit
 	if (isRelOp())
-		dim.wid += static_cast<int>(0.5 * em + 0.5);
+		dim.wid += support::iround(0.5 * em);
 	else
-		dim.wid += static_cast<int>(0.1667 * em + 0.5);
+		dim.wid += support::iround(0.1667 * em);
 
 	scriptable_ = false;
 	if (mi.base.style == LM_ST_DISPLAY)
@@ -102,14 +104,14 @@ void InsetMathSymbol::draw(PainterInfo & pi, int x, int y) const
 	bool const italic_upcase_greek = sym_->inset == "cmr" &&
 					 sym_->extra == "mathalpha" &&
 					 pi.base.fontname == "mathit";
-	docstring const font = italic_upcase_greek ? from_ascii("cmm") : sym_->inset;
-	int const em = mathed_char_width(pi.base.font, 'M');
+	std::string const font = italic_upcase_greek ? "cmm" : sym_->inset;
+	int const em = mathed_font_em(pi.base.font);
 	if (isRelOp())
-		x += static_cast<int>(0.25*em+0.5);
+		x += support::iround(0.25 * em);
 	else
-		x += static_cast<int>(0.0833*em+0.5);
+		x += support::iround(0.0833 * em);
 
-	FontSetChanger dummy(pi.base, font);
+	FontSetChanger dummy(pi.base, from_ascii(font));
 	pi.draw(x, y - h_, sym_->draw);
 }
 
@@ -271,7 +273,7 @@ void InsetMathSymbol::validate(LaTeXFeatures & features) const
 			"sup.limit{font-size: 75%;}");
 	} else {
 		if (!sym_->requires.empty())
-			features.require(to_utf8(sym_->requires));
+			features.require(sym_->requires);
 	}
 }
 
