@@ -113,7 +113,7 @@ vector<docstring> const & MacroData::defaults() const
 string const MacroData::requires() const
 {
 	if (sym_)
-		return to_utf8(sym_->requires);
+		return sym_->requires;
 	return string();
 }
 
@@ -200,7 +200,9 @@ int MacroData::write(odocstream & os, bool overwriteRedefinition) const
 	// output template
 	MathMacroTemplate const & tmpl =
 		static_cast<MathMacroTemplate const &>(*inset);
-	WriteStream wi(os, false, true, WriteStream::wsDefault);
+	TexRow texrow(false);
+	otexrowstream ots(os,texrow);
+	WriteStream wi(ots, false, true, WriteStream::wsDefault);
 	return tmpl.write(wi, overwriteRedefinition);
 }
 
@@ -243,7 +245,8 @@ MacroTable::iterator
 MacroTable::insert(Buffer * buf, docstring const & def)
 {
 	//lyxerr << "MacroTable::insert, def: " << to_utf8(def) << endl;
-	MathMacroTemplate mac(buf, def);
+	MathMacroTemplate mac(buf);
+	mac.fromString(def);
 	MacroData data(buf, mac);
 	return insert(mac.name(), data);
 }
