@@ -40,6 +40,12 @@ public:
 		wsPreview
 	};
 	///
+	enum UlemCmdType {
+		NONE,
+		UNDERLINE,
+		STRIKEOUT
+	};
+	///
 	WriteStream(otexrowstream & os, bool fragile, bool latex, OutputType output,
 				Encoding const * encoding = 0);
 	///
@@ -66,6 +72,18 @@ public:
 	void canBreakLine(bool breakline) { canbreakline_ = breakline; }
 	/// tell whether we can write an immediately following newline char
 	bool canBreakLine() const { return canbreakline_; }
+	/// record whether we have to take care for striking out display math
+	void strikeoutMath(bool mathsout) { mathsout_ = mathsout; }
+	/// tell whether we have to take care for striking out display math
+	bool strikeoutMath() const { return mathsout_; }
+	/// record which ulem command type we are inside
+	void ulemCmd(UlemCmdType ulemcmd) { ulemcmd_ = ulemcmd; }
+	/// tell which ulem command type we are inside
+	UlemCmdType ulemCmd() const { return ulemcmd_; }
+	/// record whether we are in the argument of a math macro
+	void insideMacro(bool insidemacro) { insidemacro_ = insidemacro; }
+	/// tell whether we are in the argument of a math macro
+	bool insideMacro() const { return insidemacro_; }
 	/// writes space if next thing is isalpha()
 	void pendingSpace(bool how);
 	/// writes space if next thing is isalpha()
@@ -108,6 +126,8 @@ private:
 	int latex_;
 	/// output type (default, source preview, instant preview)?
 	OutputType output_;
+	/// are we in the argument of a math macro?
+	bool insidemacro_;
 	/// do we have a space pending?
 	bool pendingspace_;
 	/// do we have a brace pending?
@@ -120,6 +140,10 @@ private:
 	bool ascii_;
 	/// are we allowed to output an immediately following newline?
 	bool canbreakline_;
+	/// should we take care for striking out display math?
+	bool mathsout_;
+	/// what ulem command are we inside (none, underline, strikeout)?
+	UlemCmdType ulemcmd_;
 	///
 	int line_;
 	///
@@ -589,6 +613,9 @@ OctaveStream & operator<<(OctaveStream &, char);
 ///
 OctaveStream & operator<<(OctaveStream &, int);
 
+
+docstring convertDelimToXMLEscape(docstring const & name);
+
 } // namespace lyx
 
 #endif
