@@ -78,7 +78,7 @@ public:
 };
 
 
-static ProgressInterface* progress_instance = 0;
+static ProgressInterface * progress_instance = 0;
 
 void ProgressInterface::setInstance(ProgressInterface* p)
 {
@@ -86,7 +86,7 @@ void ProgressInterface::setInstance(ProgressInterface* p)
 }
 
 
-ProgressInterface* ProgressInterface::instance()
+ProgressInterface * ProgressInterface::instance()
 {
 	if (!progress_instance) {
 		static ProgressDummy dummy;
@@ -101,15 +101,12 @@ ProgressInterface* ProgressInterface::instance()
 // Reuse of instance
 #ifndef USE_QPROCESS
 int Systemcall::startscript(Starttype how, string const & what,
-			    std::string const & path, bool /*process_events*/)
+			    string const & path, string const & lpath,
+			    bool /*process_events*/)
 {
-	string const python_call = "python -tt";
-	string command = to_filesystem8bit(from_utf8(latexEnvCmdPrefix(path)));
-
-	if (prefixIs(what, python_call))
-		command += os::python() + what.substr(python_call.length());
-	else
-		command += what;
+	string command =
+		to_filesystem8bit(from_utf8(latexEnvCmdPrefix(path, lpath)))
+		       + commandPrep(what);
 
 	if (how == DontWait) {
 		switch (os::shell()) {
@@ -238,15 +235,17 @@ string const parsecmd(string const & incmd, string & infile, string & outfile,
 
 
 int Systemcall::startscript(Starttype how, string const & what,
-			    string const & path, bool process_events)
+			    string const & path, string const & lpath,
+			    bool process_events)
 {
-	LYXERR(Debug::INFO,"Running: " << what);
+	string const what_ss = commandPrep(what);
+	LYXERR(Debug::INFO,"Running: " << what_ss);
 
 	string infile;
 	string outfile;
 	string errfile;
 	QString const cmd = QString::fromLocal8Bit(
-			parsecmd(what, infile, outfile, errfile).c_str());
+			parsecmd(what_ss, infile, outfile, errfile).c_str());
 
 	SystemcallPrivate d(infile, outfile, errfile);
 
@@ -256,7 +255,7 @@ int Systemcall::startscript(Starttype how, string const & what,
 	// is started with QProcess::startDetached, a console window is shown every 
 	// time a viewer is started. To avoid this, we fall back on Windows to the 
 	// original implementation that creates a QProcess object.
-	d.startProcess(cmd, path, false);
+	d.startProcess(cmd, path, lpath, false);
 	if (!d.waitWhile(SystemcallPrivate::Starting, process_events, -1)) {
 		LYXERR0("Systemcall: '" << cmd << "' did not start!");
 		LYXERR0("error " << d.errorMessage());
@@ -267,7 +266,7 @@ int Systemcall::startscript(Starttype how, string const & what,
 		return 0;
 	}
 #else
-	d.startProcess(cmd, path, how == DontWait);
+	d.startProcess(cmd, path, lpath, how == DontWait);
 	if (how == DontWait && d.state == SystemcallPrivate::Running)
 		return 0;
 
@@ -358,46 +357,31 @@ SystemcallPrivate::SystemcallPrivate(std::string const & sf,
 
 	connect(process_, SIGNAL(readyReadStandardOutput()), SLOT(stdOut()));
 	connect(process_, SIGNAL(readyReadStandardError()), SLOT(stdErr()));
+#if QT_VERSION >= 0x050600
+	connect(process_, SIGNAL(errorOccurred(QProcess::ProcessError)), SLOT(processError(QProcess::ProcessError)));
+#else
 	connect(process_, SIGNAL(error(QProcess::ProcessError)), SLOT(processError(QProcess::ProcessError)));
+#endif
 	connect(process_, SIGNAL(started()), this, SLOT(processStarted()));
 	connect(process_, SIGNAL(finished(int, QProcess::ExitStatus)), SLOT(processFinished(int, QProcess::ExitStatus)));
 }
 
 
-void SystemcallPrivate::startProcess(QString const & cmd, string const & path, bool detached)
+void SystemcallPrivate::startProcess(QString const & cmd, string const & path,
+                                     string const & lpath, bool detached)
 {
 	cmd_ = cmd;
 	if (detached) {
 		state = SystemcallPrivate::Running;
-		if (!QProcess::startDetached(toqstr(latexEnvCmdPrefix(path)) + cmd_)) {
+		if (!QProcess::startDetached(toqstr(latexEnvCmdPrefix(path, lpath)) + cmd_)) {
 			state = SystemcallPrivate::Error;
 			return;
 		}
 		QProcess* released = releaseProcess();
 		delete released;
 	} else if (process_) {
-#ifdef Q_OS_MAC
-		process_->setProcessEnvironment(QProcessEnvironment::systemEnvironment());
-		if (!lyxrc.texinputs_prefix.empty()) {
-			QProcessEnvironment environ = process_->processEnvironment();
-			string const texinputs = fromqstr(environ.value("TEXINPUTS"));
-			string const texinputs_prefix = os::latex_path_list(
-				path.empty() ? lyxrc.texinputs_prefix : replaceCurdirPath(path, lyxrc.texinputs_prefix));
-			environ.insert("TEXINPUTS", toqstr(".:" + texinputs_prefix + ':' + texinputs));
-			process_->setProcessEnvironment(environ);
-		}
-		if (!lyxrc.path_prefix.empty()) {
-			QProcessEnvironment environ = process_->processEnvironment();
-			string const path = fromqstr(environ.value("PATH"));
-			environ.insert("PATH", toqstr(lyxrc.path_prefix + ':' + path));
-			process_->setProcessEnvironment(environ);
-		}
 		state = SystemcallPrivate::Starting;
-		process_->start(cmd_);
-#else
-		state = SystemcallPrivate::Starting;
-		process_->start(toqstr(latexEnvCmdPrefix(path)) + cmd_);
-#endif
+		process_->start(toqstr(latexEnvCmdPrefix(path, lpath)) + cmd_);
 	}
 }
 
@@ -601,7 +585,7 @@ QString SystemcallPrivate::errorMessage() const
 			break;
 		case QProcess::UnknownError:
 		default:
-			message = "An unknown error occured.";
+			message = "An unknown error occurred.";
 			break;
 	}
 	return message;
@@ -631,7 +615,9 @@ QString SystemcallPrivate::exitStatusMessage() const
 
 int SystemcallPrivate::exitCode()
 {
-	if (!process_)
+	// From Qt's documentation, in regards to QProcess::exitCode(),
+	// "This value is not valid unless exitStatus() returns NormalExit"
+	if (!process_ || process_->exitStatus() != QProcess::NormalExit)
 		return -1;
 
 	return process_->exitCode();
