@@ -50,7 +50,12 @@ enum search_mode {
 	must_exist,
 	/// Only do file name expansion, return the complete name even if
 	/// the file does not exist
-	may_not_exist
+	may_not_exist,
+	/// The (image) file may be present with hi-dpi resolution -
+	/// the lookup checks for a file named "image" + "@2x" + ".ext" first.
+	/// If found it will return e.g. "image@2x.png" instead of "image.png".
+	/// Otherwise it will work as must_exist.
+	check_hidpi
 };
 
 /** Returns the real name of file name in directory path, with optional
@@ -78,6 +83,9 @@ bool isValidLaTeXFileName(std::string const & filename);
 */
 bool isValidDVIFileName(std::string const & filename);
 
+/// check whether the file has binary contents
+bool isBinaryFile(FileName const & filename);
+
 /** Returns the path of a library data file.
     Search the file name.ext in the subdirectory dir of
       -# user_lyxdir
@@ -87,7 +95,8 @@ bool isValidDVIFileName(std::string const & filename);
 */
 FileName const libFileSearch(std::string const & dir,
 				std::string const & name,
-				std::string const & ext = std::string());
+				std::string const & ext = std::string(),
+				search_mode mode = must_exist);
 
 /** Same as libFileSearch(), but tries first to find an
   internationalized version of the file by prepending $LANG_ to the
@@ -103,7 +112,8 @@ i18nLibFileSearch(std::string const & dir,
   */
 FileName const
 imageLibFileSearch(std::string & dir, std::string const & name,
-		   std::string const & ext = std::string());
+		   std::string const & ext = std::string(),
+		   search_mode mode = must_exist);
 
 /// How to quote a filename
 enum quote_style {
@@ -128,8 +138,7 @@ enum quote_style {
  *  command will still fail, but the error message will make some sort of
  *  sense ;-)
  */
-std::string const libScriptSearch(std::string const & command,
-		quote_style style = quote_shell);
+std::string const commandPrep(std::string const & command);
 
 enum latex_path_extension {
 	PROTECT_EXTENSION,
@@ -252,9 +261,9 @@ std::string const replaceEnvironmentPath(std::string const & path);
 
 /**
    Return a string to be used as a prefix to a command for setting the
-   environment of the TeX engine with respect to the path \p path.
+   environment of the TeX engine with respect to the paths \p path and \p lpath.
  */
-std::string latexEnvCmdPrefix(std::string const & path);
+std::string latexEnvCmdPrefix(std::string const &path, std::string const & lpath);
 
 /** Replace all references to a current directory (a lonely '.' or
     the prefix "./") in \c pathlist with \c path. Also prefixes
@@ -291,6 +300,9 @@ int compare_timestamps(FileName const & file1, FileName const & file2);
 bool prefs2prefs(FileName const & filename, FileName const & tempfile,
                  bool lfuns);
 
+/// Does file \p file need to be updated by configure.py?
+bool configFileNeedsUpdate(std::string const & file);
+
 typedef std::pair<int, std::string> cmd_ret;
 
 cmd_ret const runCommand(std::string const & cmd);
