@@ -12,30 +12,25 @@
 #ifndef LYX_FUNCTIONAL_H
 #define LYX_FUNCTIONAL_H
 
-#ifdef LYX_USE_TR1
+#ifdef LYX_USE_CXX11
 
 #include <functional>
-
-#ifdef __GNUC__
-#include <tr1/functional>
-#endif
-
-namespace lyx
-{
-	using std::tr1::function;
-}
+#define LYX_FUNCTIONAL_NS std
 
 #else
 
 #include <boost/function.hpp>
 #include <boost/functional.hpp>
+#define LYX_FUNCTIONAL_NS boost
+
+#endif
 
 namespace lyx
 {
-	using boost::function;
+	using LYX_FUNCTIONAL_NS::function;
 }
 
-#endif
+#undef LYX_FUNCTIONAL_NS
 
 
 #endif
