@@ -21,7 +21,7 @@ namespace lyx {
 
 /******************************************************************************
 
-LyX has five different macros that can be used to make assertions. The behave
+LyX has five different macros that can be used to make assertions. They behave
 the same way in devel mode: They assert. The differences between them are how
 they behave in release mode.
 
@@ -65,6 +65,8 @@ void doWarnIf(char const * expr, char const * file, long line);
 void doBufErr(char const * expr, char const * file, long line);
 void doAppErr(char const * expr, char const * file, long line);
 
+void doAssertWithCallstack(bool value);
+
 /// Print demangled callstack to stderr
 docstring printCallStack();
 
