@@ -15,6 +15,8 @@
 #include "support/lstrings.h"
 
 #include "support/convert.h"
+#include "support/debug.h"
+#include "support/lyxlib.h"
 #include "support/qstring_helpers.h"
 
 #include "support/lassert.h"
@@ -22,7 +24,11 @@
 #include <QString>
 
 #include <cstdio>
+#include <cstring>
 #include <algorithm>
+#include <iomanip>
+#include <sstream>
+#include <typeinfo>
 
 using namespace std;
 
@@ -32,7 +38,7 @@ namespace lyx {
 // without #include "support/docstring" there.
 docstring const & empty_docstring()
 {
-	static docstring s;
+	static const docstring s;
 	return s;
 }
 
@@ -40,7 +46,7 @@ docstring const & empty_docstring()
 // without #include <string>
 string const & empty_string()
 {
-	static string s;
+	static const string s;
 	return s;
 }
 
@@ -200,6 +206,29 @@ int compare_no_case(docstring const & s, docstring const & s2)
 }
 
 
+int compare_locale(docstring const & s, docstring const & s2)
+{
+	// FIXME We have a report that this does not work on windows (bug 9030)
+	try
+	{
+		string const l = to_local8bit(s);
+		string const r = to_local8bit(s2);
+		return strcoll(l.c_str(), r.c_str());
+	}
+	catch (bad_cast & e)
+	{
+		// fall back to builtin sorting
+		LYXERR0("Could not compare using the current locale: "
+		        << e.what() << ", using fallback.");
+		if (s < s2)
+			return -1;
+		if (s > s2)
+			return 1;
+		return 0;
+	}
+}
+
+
 namespace {
 
 template<typename Char>
@@ -1045,18 +1074,20 @@ String const doSplit(String const & a, String & piece, Char delim)
 	size_t i = a.find(delim);
 	if (i == a.length() - 1) {
 		piece = a.substr(0, i);
-	} else if (i != String::npos) {
-		piece = a.substr(0, i);
-		tmp = a.substr(i + 1);
 	} else if (i == 0) {
 		piece.erase();
 		tmp = a.substr(i + 1);
+	} else if (i != String::npos) {
+		piece = a.substr(0, i);
+		tmp = a.substr(i + 1);
 	} else {
 		piece = a;
 	}
 	return tmp;
 }
 
+
+// FIXME: why is this specialization needed?
 template<typename Char> inline
 docstring const doSplit(docstring const & a, docstring & piece, Char delim)
 {
@@ -1064,12 +1095,12 @@ docstring const doSplit(docstring const & a, docstring & piece, Char delim)
 	size_t i = a.find(delim);
 	if (i == a.length() - 1) {
 		piece = a.substr(0, i);
-	} else if (i != docstring::npos) {
-		piece = a.substr(0, i);
-		tmp = a.substr(i + 1);
 	} else if (i == 0) {
 		piece.erase();
 		tmp = a.substr(i + 1);
+	} else if (i != docstring::npos) {
+		piece = a.substr(0, i);
+		tmp = a.substr(i + 1);
 	} else {
 		piece = a;
 	}
@@ -1148,7 +1179,8 @@ docstring const escape(docstring const & lab)
 	for (size_t i = 0; i < lab.length(); ++i) {
 		char_type c = lab[i];
 		if (c >= 128 || c == '=' || c == '%' || c == '#' || c == '$'
-		    || c == '}' || c == '{' || c == ']' || c == '[' || c == '&') {
+		    || c == '}' || c == '{' || c == ']' || c == '[' || c == '&'
+		    || c == '\\') {
 			// Although char_type is a 32 bit type we know that
 			// UCS4 occupies only 21 bits, so we don't need to
 			// encode bigger values. Test for 2^24 because we
@@ -1170,6 +1202,17 @@ docstring const escape(docstring const & lab)
 }
 
 
+bool truncateWithEllipsis(docstring & str, size_t const len)
+{
+	if (str.size() <= len)
+		return false;
+	str.resize(len);
+	if (len > 0)
+		str[len - 1] = 0x2026;// HORIZONTAL ELLIPSIS
+	return true;
+}
+
+
 namespace {
 
 // this doesn't check whether str is empty, so do that first.
@@ -1193,7 +1236,7 @@ vector<docstring> wrapToVec(docstring const & str, int ind,
 		size_t const i = s.find_last_of(' ', width - 1);
 		if (i == docstring::npos || i <= size_t(ind)) {
 			// no space found
-			s = s.substr(0, width - 3) + "...";
+			truncateWithEllipsis(s, width);
 			break;
 		}
 		retval.push_back(s.substr(0, i));
@@ -1222,7 +1265,6 @@ docstring wrap(docstring const & str, int const ind, size_t const width)
 docstring wrapParas(docstring const & str, int const indent,
 		    size_t const width, size_t const maxlines)
 {
-	docstring const dots = from_ascii("...");
 	if (str.empty())
 		return docstring();
 
@@ -1241,15 +1283,15 @@ docstring wrapParas(docstring const & str, int const indent,
 			tmp.resize(maxlines - curlines);
 			docstring last = tmp.back();
 			size_t const lsize = last.size();
-			if (lsize > width - 3) {
-				size_t const i = last.find_last_of(' ', width - 3);
+			if (lsize > width - 1) {
+				size_t const i = last.find_last_of(' ', width - 1);
 				if (i == docstring::npos || i <= size_t(indent))
 					// no space found
-					last = last.substr(0, lsize - 3) + dots;
+					truncateWithEllipsis(last, lsize);
 				else
-					last = last.substr(0, i) + dots;
+					truncateWithEllipsis(last, i);
 			} else
-				last += dots;
+				last.push_back(0x2026);//HORIZONTAL ELLIPSIS
 			tmp.pop_back();
 			tmp.push_back(last);
 		}
@@ -1359,6 +1401,25 @@ int findToken(char const * const str[], string const & search_token)
 }
 
 
+std::string formatFPNumber(double x)
+{
+	// Need manual tweaking, QString::number(x, 'f', 16) does not work either
+	ostringstream os;
+	os << std::fixed;
+	// Prevent outputs of 23.4200000000000017 but output small numbers
+	// with at least 6 significant digits.
+	double const logarithm = log10(fabs(x));
+	os << std::setprecision(max(6 - iround(logarithm), 0)) << x;
+	string result = os.str();
+	if (result.find('.') != string::npos) {
+		result = rtrim(result, "0");
+		if (result[result.length()-1] == '.')
+			result = rtrim(result, ".");
+	}
+	return result;
+}
+
+
 template<>
 docstring bformat(docstring const & fmt, int arg1)
 {
