@@ -71,17 +71,19 @@ def main(argv):
         files = [sys.argv[4+skipcount]]
     else:
         files = ['test.ltx', \
+                 'algo2e.tex', \
                  'box-color-size-space-align.tex', \
                  'CJK.tex', \
                  'CJKutf8.tex', \
                  'test-insets.tex', \
+                 'test-insets-basic.tex', \
                  'test-memoir.tex', \
                  'test-modules.tex', \
                  'test-refstyle-theorems.tex', \
+                 'test-scr.tex', \
                  'test-structure.tex', \
                  'verbatim.tex', \
-                 'XeTeX-polyglossia.tex', \
-                 'algo2e.tex']
+                 'XeTeX-polyglossia.tex']
 
     errors = []
     overwrite = (outputdir == inputdir)
@@ -122,6 +124,12 @@ def main(argv):
                     f1 = open(lyxfile1, 'r')
                     f2 = open(lyxfile2, 'r')
                     lines1 = f1.readlines()
+                    i1 = 0
+                    for linex in lines1:
+                      if linex[:-1] == '\origin ' + inputdir + '/':
+                        lines1[i1] = '\origin ' + outputdir + '/' + "\n"
+                        break
+                      i1 = i1+1
                     lines2 = f2.readlines()
                     f1.close()
                     f2.close()
@@ -139,6 +147,7 @@ def getlyxinput(lyx, lyxfx, lyxf, uselyx2lyx):
     if uselyx2lyx:
         cmd = '%s -E lyx %s %s' % (lyx, lyxf, lyxfx)
         sys.stdout.writelines(cmd)
+        sys.stdout.writelines("\n")
         if os.system(cmd) != 0:
             return None
         return lyxf
